*Child and youth poverty analysis for the Somali Poverty Profile 2016

set more off
set seed 23081280 
set sortseed 12031585

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}


*Integrate the dataset for the analysis
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", nogen assert(match) keepusing(astrata weight_cons poorPPP remit12m hhh_gender hhh_age hhh_edu floor_material roof_material toilet_type water treated_water hunger)
merge m:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", nogen assert(master match) keepusing(poorPPP125_prob)
svyset ea [pweight=weight_cons], strata(strata)
*Include the regional breakdown 
gen ind_profile=6 if astrata==3
replace ind_profile=5 if astrata==22
replace ind_profile=4 if astrata==21
replace ind_profile=3 if astrata==14 | astrata==15
replace ind_profile=2 if astrata==12 | astrata==13 
replace ind_profile=1 if astrata==11
label define lind_profile 1 "Mogadishu (Urban)" 2 "North-east Urban (Nugaal,Bari,Mudug)" 3 "North-west Urban (Woqooyi G,Awdal,Sanaag,Sool,Togdheer)" 4 "North-east Rural (Bari,Mudug,Nugaal)" 5 "North-west Rural (Awdal,Sanaag,Sool,Togdheer,Woqooyi)" 6 "IDP Settlements"
label values ind_profile lind_profile
label var ind_profile "Indicator: Mogadishu, North-East urban/rural, North-West urban/rural & IDPs"
*Define dummy variables for child and youth 
drop youth 
gen child=1 if age<=14 & !missing(age)
replace child=0 if child==. & !missing(age)
gen youth=1 if age<=24 & age>=15 & !missing(age)
replace youth=0 if youth==. & !missing(age)
bys strata ea block hh: egen no_child_hh=sum(child)
bys strata ea block hh: egen no_youth_hh=sum(youth)
gen no_child_hh_cat=0 if no_child_hh==0
replace no_child_hh_cat=1 if no_child_hh>=1 & no_child_hh<=3
replace no_child_hh_cat=2 if no_child_hh>=4
label define lno_child_hh_cat 0 "Zero children in hh" 1 "1-3 children in hh" 2 "4 or more children in hh"
label values no_child_hh_cat lno_child_hh_cat
label var no_child_hh_cat "Category for no. of children in the household"
*Define dummy variables for age and education of hh head
gen hhh_age_cat=1 if hhh_age>=25 & hhh_age<=40 
replace hhh_age_cat=2 if hhh_age>=41 
label define lhhh_age_cat 1 "25-40" 2 "41 or older"
label values hhh_age_cat lhhh_age_cat
label var hhh_age_cat "Age category for hh head"
recode hhh_edu (0 = 1 "No Education") (1/6 = 2 "Education"), generate(hhh_edu_cat)
label var hhh_edu_cat "Education category for hh head"
*Define dummy for number of adults per household
gen adult=1 if age>=25 & !missing(age)
bys strata ea block hh: egen no_adults=sum(adult)
gen no_adults_cat=1 if no_adults>=1 & no_adults<=2
replace no_adults_cat=2 if no_adults>=3 
label define lno_adults_cat 1 "1 or 2 adults" 2 "3 or more"
label values no_adults_cat lno_adults_cat
label var no_adults_cat "No of adults in the hh category"
*Literacy rate of adults in household 
bys strata ea block hh: egen pre_no_lit=sum(literacy) if adult==1 
bys strata ea block hh: egen no_lit=max(pre_no_lit)
gen adults_lit_cat=0 if no_lit==0
replace adults_lit_cat=1 if no_lit==1
replace adults_lit_cat=2 if no_lit>=2 & !missing(no_lit)
label define ladults_lit_cat 0 "None" 1 "One member" 2 "2 or more"
label values adults_lit_cat ladults_lit_cat
label var adults_lit_cat "No of literate members in the hh"
*Skill level of adults in the household
gen skill_level=1 if isco==9 |  isco==10
replace skill_level=2 if isco==4 |  isco==5 |  isco==6 |  isco==7 |  isco==8
replace skill_level=3 if isco==1 |  isco==3
replace skill_level=4 if isco==2
bys strata ea block hh: egen pre_skills_hh=sum(skill_level) if adult==1 
bys strata ea block hh: egen skills_hh=max(pre_skills_hh)
gen adults_skills_cat=0 if skills_hh==0
replace adults_skills_cat=1 if skills_hh==1 | skills_hh==2
replace adults_skills_cat=2 if skills_hh==3 | skills_hh==4
replace adults_skills_cat=3 if skills_hh>=5
label define ladults_skills_cat 0 "None" 1 "One adult w/low skills" 2 "One adult w/high skills" 3 "More than 1 adult w/skills"
label values adults_skills_cat ladults_skills_cat
label var adults_skills_cat "No of skilled adults in the hh"
*Multidimensional poverty 
*Education: child in primary age not in school
gen notinschool = (hhm_edu_current==0 & inrange(age, 6, 18))
la def notinschool 0 "Child not of school age or enrolled" 1 "Child of school age not enrolled" 
la val notinschool lnotinschool
*Information: youth live in a households w/access to information
preserve
use "${gsdData}/1-CleanOutput/assets.dta", clear 
merge m:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen keep(match)
keep if itemid==26 | itemid==28 |  itemid==30 | itemid==31
gen access_info=1 
collapse (max) access_info, by(strata ea block hh ind_profile)
save "${gsdTemp}/access_info_childpoverty.dta", replace
restore
merge m:1 strata ea block hh using "${gsdTemp}/access_info_childpoverty.dta", nogen keep(master match) keepusing(access_info)
replace access_info=0 if access_info==.
la var access_info "The household owns a radio, tv or computer"
label define laccess_info 1 "Owns radio, tv and/or computer" 0 "Does not own"
label values access_info laccess_info
*Water: child without access to improved water source 
gen water_improved=1 if water==1 | water==2
replace water_improved=0 if water_improved==.
label define lwater_improved 1 "Has access to improved sources" 0 "Does not have access"
label values water_improved lwater_improved
*Sanitation: child without access to improved saniation 
gen sanitation_improved=1 if toilet_type==1 | toilet_type==2
replace sanitation_improved=0 if sanitation_improved==.
label define lsanitation_improved 1 "Has access to improved sources" 0 "Does not have access"
label values sanitation_improved lsanitation_improved
*Deprivation in two dimensions
gen con_edu = (poorPPP==1 & notinschool==1)
gen con_wat = (poorPPP==1 & water_improved==0)
gen con_san = (poorPPP==1 & sanitation_improved==0)
gen edu_wat = (notinschool==1 & water_improved==0)
gen edu_san = (notinschool==1 & sanitation_improved==0)
gen wat_san = (water_improved==0 & sanitation_improved==0)
*Deprivation in three dimensions
gen con_edu_wat = (poorPPP==1 & notinschool==1 & water_improved==0)
gen con_edu_san = (poorPPP==1 & notinschool==1 & sanitation_improved==0)
gen con_wat_san = (poorPPP==1 & sanitation_improved==0 & water_improved==0)
gen edu_wat_san = (sanitation_improved==0 & notinschool==1 & water_improved==0)
*Deprivation in four dimensions
gen con_edu_wat_san = (poorPPP==1 & notinschool==1 & water_improved==0 & sanitation_improved==0)
*Include migration variable at the household level
preserve 
gen migrant=1 if hh_alwayslived==0 & age>=25 & !missing(age)
replace migrant=0 if hh_alwayslived==1
gen migrant_head=1 if migrant==1 & ishead==1
replace migrant_head=0 if migrant_head==.
collapse (sum) migrant migrant_head, by(strata ea block hh hhsize weight_cons ind_profile poorPPP)
rename migrant migrant_hh
save "${gsdTemp}/migration_hh.dta", replace
restore
merge m:1 strata ea block hh using "${gsdTemp}/migration_hh.dta", nogen assert(master match) keepusing(migrant_hh migrant_head)
*Label the variables
la def ldeprived 1 "Deprived" 0 "Not deprived" 
foreach v of varlist con_* edu_* {
	la val `v' ldeprived
}
save "${gsdData}/1-CleanTemp/hhm_child_poverty.dta", replace


*Child poverty headcount ratio 
qui tabout child poorPPP using "${gsdOutput}/Child_Poverty_1.xls", svy c(freq se) sebnone h1(Child poverty - Overall) replace
forval i=1/6 {
	qui tabout child poorPPP  using "${gsdOutput}/Child_Poverty_1.xls" if ind_profile==`i', svy c(freq se lb ub) sebnone h1(Child poverty - by region `i') append
}
qui tabout poorPPP remit12m using "${gsdOutput}/Child_Poverty_1.xls" if child==1, svy c(freq se lb ub) sebnone h1(Child poverty - by remittances) append
qui tabout poorPPP hhh_gender using "${gsdOutput}/Child_Poverty_1.xls" if child==1, svy c(freq se lb ub) sebnone h1(Child poverty - by gender of hh head) append
qui tabout poorPPP hhh_age_cat using "${gsdOutput}/Child_Poverty_1.xls" if child==1, svy c(freq se lb ub) sebnone h1(Child poverty - by age of hh head) append
qui tabout poorPPP hhh_edu_cat using "${gsdOutput}/Child_Poverty_1.xls" if child==1, svy c(freq se lb ub) sebnone h1(Child poverty - by education of hh head) append
qui tabout poorPPP no_adults_cat using "${gsdOutput}/Child_Poverty_1.xls" if child==1, svy c(freq se lb ub) sebnone h1(Child poverty - by no. of adults in the hh) append
*Check if the differences are statistically significant
preserve
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
svy: mean poorPPP if child==1, over(hhh_gender)
test [poorPPP]Female = [poorPPP]Male
svy: mean poorPPP if child==1, over(remit12m)
test [poorPPP]No = [poorPPP]Yes
svy: mean poorPPP if child==1, over(hhh_age_cat)
test [poorPPP]_subpop_1 = [poorPPP]_subpop_2
svy: mean poorPPP if child==1, over(hhh_edu_cat)
test [poorPPP]_subpop_1 = [poorPPP]Education
svy: mean poorPPP if child==1, over(no_adults_cat)
test [poorPPP]_subpop_1 = [poorPPP]_subpop_2
restore
*Extreme poverty  
replace poorPPP125_prob=poorPPP125_prob*100
qui tabout ind_profile using "${gsdOutput}/Child_Poverty_1.xls" if child==1, svy sum c(mean poorPPP125_prob se lb ub) sebnone h2(Extreme child poverty - Overall) append
*Poverty and migration
qui tabout poorPPP using "${gsdOutput}/Child_Poverty_1.xls" if child==1 & migrant_hh==0, svy c(freq se lb ub) sebnone h2(Child poverty - in households w/o migrants) append
qui tabout poorPPP using "${gsdOutput}/Child_Poverty_1.xls" if child==1 & migrant_hh>=1, svy c(freq se lb ub) sebnone h2(Child poverty - in households with migrants) append
qui tabout poorPPP using "${gsdOutput}/Child_Poverty_1.xls" if child==1 & migrant_head==0, svy c(freq se lb ub) sebnone h2(Child poverty - in households w/o migrant head) append
qui tabout poorPPP using "${gsdOutput}/Child_Poverty_1.xls" if child==1 & migrant_head>=1, svy c(freq se lb ub) sebnone h2(Child poverty - in households with migrant head) append


*Youth poverty headcount ratio  
qui tabout youth poorPPP using "${gsdOutput}/Child_Poverty_2.xls", svy c(freq se) sebnone h1(Youth poverty - Overall) replace
forval i=1/6 {
	qui tabout youth poorPPP using "${gsdOutput}/Child_Poverty_2.xls" if ind_profile==`i', svy c(freq se lb ub) sebnone h1(Youth poverty - by region `i') append
}
qui tabout poorPPP remit12m using "${gsdOutput}/Child_Poverty_2.xls" if youth==1, svy c(freq se lb ub) sebnone h1(Youth poverty - by remittances) append
qui tabout poorPPP hhh_gender using "${gsdOutput}/Child_Poverty_2.xls" if youth==1, svy c(freq se lb ub) sebnone h1(Youth poverty - by gender of hh head) append
qui tabout poorPPP hhh_age_cat using "${gsdOutput}/Child_Poverty_2.xls" if youth==1, svy c(freq se lb ub) sebnone h1(Youth poverty - by age of hh head) append
qui tabout poorPPP hhh_edu_cat using "${gsdOutput}/Child_Poverty_2.xls" if youth==1, svy c(freq se lb ub) sebnone h1(Youth poverty - by education of hh head) append
qui tabout poorPPP no_adults_cat using "${gsdOutput}/Child_Poverty_2.xls" if youth==1, svy c(freq se lb ub) sebnone h1(Youth poverty - by no. of adults in the hh) append
*Check if the differences are statistically significant
preserve
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
svy: mean poorPPP if youth==1, over(hhh_gender)
test [poorPPP]Female = [poorPPP]Male
svy: mean poorPPP if youth==1, over(remit12m)
test [poorPPP]No = [poorPPP]Yes
svy: mean poorPPP if youth==1, over(hhh_age_cat)
test [poorPPP]_subpop_1 = [poorPPP]_subpop_2
svy: mean poorPPP if youth==1, over(hhh_edu_cat)
test [poorPPP]_subpop_1 = [poorPPP]Education
svy: mean poorPPP if youth==1, over(no_adults_cat)
test [poorPPP]_subpop_1 = [poorPPP]_subpop_2
restore
*Extreme poverty  
qui tabout ind_profile using "${gsdOutput}/Child_Poverty_2.xls" if youth==1, svy sum c(mean poorPPP125_prob se lb ub) sebnone h2(Extreme youth poverty - Overall) append
*Poverty and migration
qui tabout poorPPP using "${gsdOutput}/Child_Poverty_2.xls" if youth==1 & hh_alwayslived==0, svy c(freq se lb ub) sebnone h2(Youth poverty - for youth migrants) append
qui tabout poorPPP using "${gsdOutput}/Child_Poverty_2.xls" if youth==1 & hh_alwayslived==1, svy c(freq se lb ub) sebnone h2(Youth poverty - for youth that have not migrated) append


*Multidimensional poverty for child
qui tabout notinschool ind_profile using "${gsdOutput}/Child_Poverty_3.xls" if child==1, svy percent c(col) sebnone npos(col) h1(notinschool  deprived - child) replace
qui foreach var of varlist water_improved sanitation_improved {
	tabout `var' ind_profile using "${gsdOutput}/Child_Poverty_3.xls" if child==1, svy percent c(col) sebnone npos(col) h1(`var' deprived - child) append
}
qui foreach var of varlist con_edu con_wat con_san edu_wat edu_san wat_san {
	tabout `var' ind_profile using "${gsdOutput}/Child_Poverty_3.xls" if child==1, svy percent c(col) sebnone npos(col) h1(`var' deprived - child) append
}
qui foreach var of varlist con_edu_wat con_edu_san con_wat_san edu_wat_san {
	tabout `var' ind_profile using "${gsdOutput}/Child_Poverty_3.xls" if child==1, svy percent c(col) sebnone npos(col) h1(`var' deprived - child) append
}
qui tabout con_edu_wat_san ind_profile using "${gsdOutput}/Child_Poverty_3.xls" if child==1, svy percent c(col) sebnone npos(col) h1(four-dimension deprived - child) append
*New approach: children deprive in at least i dimension(s)
gen depr_nc= poorPPP + (notinschool==1) + (water_improved==0) + (sanitation_improved==0) if child==1
qui forvalues i=1/4 {
	gen depr_c`i' = depr_nc>=`i' if !missing(depr_nc) & child==1
	tabout depr_c`i' ind_profile using "${gsdOutput}/Child_Poverty_3.xls" if child==1, svy percent c(col) sebnone f(3) h1(Child deprivation in `i' dimension) append
}


*Multidimensional poverty for youth
qui tabout notinschool ind_profile using "${gsdOutput}/Child_Poverty_4.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(notinschool  deprived - youth) replace
qui foreach var of varlist water_improved sanitation_improved {
	tabout `var' ind_profile using "${gsdOutput}/Child_Poverty_4.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(`var' deprived - child) append
}
qui foreach var of varlist con_edu con_wat con_san edu_wat edu_san wat_san {
	tabout `var' ind_profile using "${gsdOutput}/Child_Poverty_4.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(`var' deprived - youth) append
}
qui foreach var of varlist con_edu_wat con_edu_san con_wat_san edu_wat_san {
	tabout `var' ind_profile using "${gsdOutput}/Child_Poverty_4.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(`var' deprived - youth) append
}
qui tabout con_edu_wat_san ind_profile using "${gsdOutput}/Child_Poverty_4.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(four-dimension deprived - youth) append
qui tabout access_info ind_profile using "${gsdOutput}/Child_Poverty_4.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(access_info  deprived - youth) append
*New approach: youth deprive in at least i dimension(s)
gen depr_ny= poorPPP + (access_info==0) + (water_improved==0) + (sanitation_improved==0) if youth==1
qui forvalues i=1/4 {
	gen depr_y`i' = depr_ny>=`i' if !missing(depr_ny) & youth==1
	tabout depr_y`i' ind_profile using "${gsdOutput}/Child_Poverty_4.xls" if youth==1, svy percent c(col) sebnone f(3) h1(Youth deprivation in `i' dimension) append
}


*Age distribution 
qui tabout age_cat_narrow gender using "${gsdOutput}/Child_Poverty_5.xls", svy c(freq se) f(3) sebnone h1(Age distribution by gender) replace
qui tabout age_cat_narrow gender using "${gsdOutput}/Child_Poverty_5.xls" if poorPPP==1, svy c(freq se) f(3) sebnone h1(Age distribution for poor by gender) append
qui tabout age_cat_narrow gender using "${gsdOutput}/Child_Poverty_5.xls" if poorPPP==0, svy c(freq se) f(3) sebnone h1(Age distribution for non-poor by gender) append
*Check if differences between gender by age group are significant
preserve
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
forval i=1/6 {
svy: mean poorPPP if age_cat_narrow==`i', over(gender)
test [poorPPP]Female = [poorPPP]Male
}
restore


*Migration status
gen migrant=1 if hh_alwayslived==0 & age>=25 & !missing(age)
replace migrant=0 if hh_alwayslived==1
qui tabout hh_alwayslived ind_profile using "${gsdOutput}/Child_Poverty_5.xls" if youth==1, svy percent c(col) sebnone h1(Migration - by youth) append
preserve
keep if no_child_hh>0
collapse (sum) migrant, by(strata ea block hh hhsize weight_cons ind_profile)
qui tabout migrant ind_profile using "${gsdOutput}/Child_Poverty_5.xls", svy percent c(col) sebnone npos(col) h1(Share of households with adult migrants) append
restore


*Number of children in the household and other indicators
*Poverty
qui tabout poorPPP using "${gsdOutput}/Child_Poverty_5.xls" if no_child_hh_cat==0, svy c(freq se lb ub) sebnone h2(Child poverty - for hhs with zero children) append
qui tabout poorPPP using "${gsdOutput}/Child_Poverty_5.xls" if no_child_hh_cat==1, svy c(freq se lb ub) sebnone h2(Child poverty - for hhs with 1-3 children) append
qui tabout poorPPP using "${gsdOutput}/Child_Poverty_5.xls" if no_child_hh_cat==2, svy c(freq se lb ub) sebnone h2(Child poverty - for hhs with 4 or more children) append
preserve 
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
svy: mean poorPPP, over(no_child_hh_cat)
test [poorPPP]_subpop_1 = [poorPPP]_subpop_2= [poorPPP]_subpop_3
restore
*School attendance for child
qui tabout hhm_edu_current using "${gsdOutput}/Child_Poverty_5.xls" if child==1 & age >=6 & no_child_hh_cat==1, svy percent c(col) sebnone npos(col) h2(School attendance of child for those in hhs with 1-3 children) append
qui tabout hhm_edu_current using "${gsdOutput}/Child_Poverty_5.xls" if child==1 & age >=6 & no_child_hh_cat==2, svy percent c(col) sebnone npos(col) h2(School attendance of child for those in hhs with 4 or more children) append
preserve 
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
drop if no_child_hh_cat==0
svy: mean hhm_edu_current if child==1 & age >=6, over(no_child_hh_cat)
test [hhm_edu_current]_subpop_1 = [hhm_edu_current]_subpop_2
restore
*Remittances
qui tabout remit12m using "${gsdOutput}/Child_Poverty_5.xls" if no_child_hh_cat==0, svy percent c(col) sebnone npos(col) h2(Remittances status for those in hhs with zero children) append
qui tabout remit12m using "${gsdOutput}/Child_Poverty_5.xls" if no_child_hh_cat==1, svy percent c(col) sebnone npos(col) h2(Remittances status for those in hhs with 1-3 children) append
qui tabout remit12m using "${gsdOutput}/Child_Poverty_5.xls" if no_child_hh_cat==2, svy percent c(col) sebnone npos(col) h2(Remittances status for those in hhs with 4 or more children) append
*Migration 
gen migrant_hh_cat=0 if migrant_hh==0
replace migrant_hh_cat=1 if migrant_hh>=1
qui tabout migrant_hh_cat using "${gsdOutput}/Child_Poverty_5.xls" if no_child_hh_cat==0, svy percent c(col) sebnone h2(Household migration - in hhs with zero children) append
qui tabout migrant_hh_cat using "${gsdOutput}/Child_Poverty_5.xls" if no_child_hh_cat==1, svy percent c(col) sebnone h2(Household migration - in hhs with 1-3 children) append
qui tabout migrant_hh_cat using "${gsdOutput}/Child_Poverty_5.xls" if no_child_hh_cat==2, svy percent c(col) sebnone h2(Household migration - in hhs with 4 or more children) append
preserve 
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
svy: mean migrant_hh_cat, over(no_child_hh_cat)
test [migrant_hh_cat]_subpop_1 = [migrant_hh_cat]_subpop_2 = [migrant_hh_cat]_subpop_3
restore


*School attendance for child and absence reasons
qui tabout hhm_edu_current ind_profile using "${gsdOutput}/Child_Poverty_6.xls" if child==1 & age >=6 , svy percent c(col) sebnone npos(col) h1(School attendance of child by ind_profile) replace
qui foreach var of varlist poorPPP hhh_gender hhh_age_cat hhh_edu_cat no_adults_cat adults_lit_cat adults_skills_cat remit12m {
	qui tabout hhm_edu_current `var' using "${gsdOutput}/Child_Poverty_6.xls" if child==1 & age >=6 , svy percent c(col) sebnone npos(col) h1(School attendance of child by `var') append
}
qui tabout absent_reason ind_profile using "${gsdOutput}/Child_Poverty_6.xls" if child==1 & age >=6 , svy percent c(col) sebnone npos(col) h1(Absence reasons of child by ind_profile) append
*Check if the differences are statistically significant
preserve
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
svy: mean hhm_edu_current if child==1, over(poorPPP)
test [hhm_edu_current]_subpop_1 = [hhm_edu_current]Poor
svy: mean hhm_edu_current if child==1, over(hhh_gender)
test [hhm_edu_current]Female = [hhm_edu_current]Male
svy: mean hhm_edu_current if child==1, over(remit12m)
test [hhm_edu_current]No = [hhm_edu_current]Yes
svy: mean hhm_edu_current if child==1, over(hhh_age_cat)
test [hhm_edu_current]_subpop_1 = [hhm_edu_current]_subpop_2
svy: mean hhm_edu_current if child==1, over(hhh_edu_cat)
test [hhm_edu_current]_subpop_1 = [hhm_edu_current]Education
svy: mean hhm_edu_current if child==1, over(no_adults_cat)
test [hhm_edu_current]_subpop_1 = [hhm_edu_current]_subpop_2
svy: mean hhm_edu_current if child==1, over(adults_lit_cat)
test [hhm_edu_current]None = [hhm_edu_current]_subpop_2= [hhm_edu_current]_subpop_3
svy: mean hhm_edu_current if child==1, over(adults_skills_cat)
test [hhm_edu_current]None = [hhm_edu_current]_subpop_2= [hhm_edu_current]_subpop_3
restore


*School attendance for youth and absence reasons
qui tabout hhm_edu_current ind_profile using "${gsdOutput}/Child_Poverty_7.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(School attendance of youth by ind_profile) replace
qui foreach var of varlist poorPPP hhh_gender hhh_age_cat hhh_edu_cat no_adults_cat adults_lit_cat adults_skills_cat remit12m {
	qui tabout hhm_edu_current `var' using "${gsdOutput}/Child_Poverty_7.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(School attendance of youth by `var') append
}
qui tabout absent_reason ind_profile using "${gsdOutput}/Child_Poverty_7.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(Absence reasons of youth by ind_profile) append
*Check if the differences are statistically significant
preserve
svyset ea [pweight=weight_cons], strata(strata) singleunit(centered)
svy: mean hhm_edu_current if youth==1, over(poorPPP)
test [hhm_edu_current]_subpop_1 = [hhm_edu_current]Poor
svy: mean hhm_edu_current if youth==1, over(hhh_gender)
test [hhm_edu_current]Female = [hhm_edu_current]Male
svy: mean hhm_edu_current if youth==1, over(remit12m)
test [hhm_edu_current]No = [hhm_edu_current]Yes
svy: mean hhm_edu_current if youth==1, over(hhh_age_cat)
test [hhm_edu_current]_subpop_1 = [hhm_edu_current]_subpop_2
svy: mean hhm_edu_current if youth==1, over(hhh_edu_cat)
test [hhm_edu_current]_subpop_1 = [hhm_edu_current]Education
svy: mean hhm_edu_current if youth==1, over(no_adults_cat)
test [hhm_edu_current]_subpop_1 = [hhm_edu_current]_subpop_2
svy: mean hhm_edu_current if youth==1, over(adults_lit_cat)
test [hhm_edu_current]None = [hhm_edu_current]_subpop_2= [hhm_edu_current]_subpop_3
svy: mean hhm_edu_current if youth==1, over(adults_skills_cat)
test [hhm_edu_current]None = [hhm_edu_current]_subpop_2= [hhm_edu_current]_subpop_3
restore


*Housing conditions for child and youth
qui tabout floor_material ind_profile using "${gsdOutput}/Child_Poverty_8.xls" if child==1, svy percent c(col) sebnone npos(col) h1(Floor type by status - child) replace
qui foreach var of varlist roof_material toilet_type water treated_water {
	tabout `var' ind_profile using "${gsdOutput}/Child_Poverty_8.xls" if child==1, svy percent c(col) sebnone npos(col) h1(`var' by status - child) append
}
qui tabout floor_material ind_profile using "${gsdOutput}/Child_Poverty_9.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(`var' by status - youth) replace
qui foreach var of varlist roof_material toilet_type water treated_water {
	tabout `var' ind_profile using "${gsdOutput}/Child_Poverty_9.xls" if youth==1, svy percent c(col) sebnone npos(col) h1(`var' by status - youth) append
}



* Put all created sheets into one excel document
foreach i of numlist 1/9 {
	insheet using "${gsdOutput}/Child_Poverty_`i'.xls", clear nonames tab
	export excel using "${gsdOutput}/Child_Poverty_Figures_Final.xlsx", sheetreplace sheet("Raw_Data_`i'") 
	erase "${gsdOutput}/Child_Poverty_`i'.xls"
}
