*Create maps for the Somali Poverty Profile 2016

set more off
set seed 21083380 
set sortseed 12031181

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}


*Open the dataset for the analysis
use "${gsdData}/1-CleanOutput/hh.dta", clear
gen pweight=weight_cons*hhsize
svyset ea [pweight=pweight], strata(strata)


*Generate ID according to the shape file
gen id_map=1 if reg_pess==1
replace id_map=3 if reg_pess==2
replace id_map=4 if reg_pess==3
replace id_map=11 if reg_pess==4
replace id_map=12 if reg_pess==5
replace id_map=13 if reg_pess==6
replace id_map=16 if reg_pess==7
replace id_map=17 if reg_pess==8
replace id_map=18 if reg_pess==9


*Obtain variables of interest for the maps 
gen gini=.
levelsof id_map, local(region) 
quietly foreach i of local region {
	fastgini tc_imp [pweight=pweight] if id_map==`i'
	return list 
	gen gini_region_`i'=r(gini) 
	replace gini=gini_region_`i' if id_map==`i'
	drop gini_region_`i'
}
gen hhh_female=1 if hhh_gender==0
replace hhh_female=0 if hhh_gender==1
gen toilet =toilet_type
replace toilet =1 if inlist(toilet_type,1,1000)
replace toilet =0 if inlist(toilet_type,2,3,4)
qui foreach var of varlist gini poorPPP_prob pliteracy remit12m hhh_female toilet {
	replace `var'=`var'*100
	format `var' %4.0f
}		


*Collapse the dataset at the region level (including IDPs)
collapse (max) gini (mean) poorPPP_prob pliteracy remit12m hhh_female toilet [pw=pweight], by(id_map)


*Add regions not included in the survey (including IDPs)
merge 1:1 id_map using "${gsdData}/1-CleanInput/SOM_db.dta", nogen keepusing(ISO)


*Create a coverage map for SL, Wave 1 and Wave 2 
gen slhs=1 if id_map==1 |  id_map==13 |  id_map==16 |  id_map==17 |  id_map==18
gen wave1=1 if poorPPP_prob<.
gen wave2=1 if id_map!=9

spmap slhs using "${gsdData}/1-CleanInput/SOM_coord.dta", id(id_map) fcolor(eltblue) ///
legend(label(2 "Region covered") label(1 "Region not covered")) ndfcolor(gs13) ///
legstyle(2) legend(position(4)) title("SLHS, 2013") 
graph save Graph "${gsdOutput}/Map_Coverage_SLHS.gph", replace

spmap wave1 using "${gsdData}/1-CleanInput/SOM_coord.dta", id(id_map) fcolor(ebblue) ///
legend(label(2 "Region covered") label(1 "Region not covered")) ndfcolor(gs13) ///
legstyle(2) legend(position(4)) title("SHFS, Wave 1 (2016)") 
graph save Graph "${gsdOutput}/Map_Coverage_Wave1.gph", replace

spmap wave2 using "${gsdData}/1-CleanInput/SOM_coord.dta", id(id_map) fcolor(edkblue) ///
legend(label(2 "Region covered") label(1 "Region not covered")) ndfcolor(gs13) ///
legstyle(2) legend(position(4)) title("SHFS, Wave 2 (2017)") 
graph save Graph "${gsdOutput}/Map_Coverage_Wave2.gph", replace


*Create poverty map (including IDPs)
spmap poorPPP_prob using "${gsdData}/1-CleanInput/SOM_coord.dta", id(id_map) fcolor(Reds) ///
clmethod(custom) clnumber(6) clbreaks(10 20 30 40 50 60 70) ndlabel(Not covered by SHFS 2016) legstyle(2) legend(position(4)) ///
ndfcolor(gs13) title("Poverty Incidence") subtitle("% of population below US$ 1.9 (PPP) per day") 
graph save Graph "${gsdOutput}/Map_Poverty.gph", replace

*Create inequality map (including IDPs)
spmap gini using "${gsdData}/1-CleanInput/SOM_coord.dta", id(id_map) fcolor(Oranges) ///
clmethod(custom) clnumber(7) clbreaks(20 25 30 35 40 45) ndlabel(Not covered by SHFS 2016) legstyle(2) legend(position(4)) ///
ndfcolor(gs13) title("Inequality") subtitle("GINI Coefficient (0-100)") 
graph save Graph "${gsdOutput}/Map_Inequality.gph", replace


*Create map on remittances (including IDPs)
spmap remit12m using "${gsdData}/1-CleanInput/SOM_coord.dta", id(id_map) fcolor(Heat) ///
clmethod(custom) clnumber(7) clbreaks(10 15 20 25 30 35) ndlabel(Not covered by SHFS 2016) legstyle(2) legend(position(4)) ///
ndfcolor(gs13) title("Recipients of remittances") subtitle("(% of households)") 
graph save Graph "${gsdOutput}/Map_Remittances.gph", replace


*Create map on hh headed by a women (including IDPs)
spmap hhh_female using "${gsdData}/1-CleanInput/SOM_coord.dta", id(id_map) fcolor(Blues) ///
clmethod(custom) clnumber(7) clbreaks(30 40 50 60 70 80) ndlabel(Not covered by SHFS 2016) legstyle(2) legend(position(4)) ///
ndfcolor(gs13) title("Households headed by a women") subtitle("(% of households)") 
graph save Graph "${gsdOutput}/Map_Femalehhh.gph", replace


*Create map on literacy rate (including IDPs)
spmap pliteracy using "${gsdData}/1-CleanInput/SOM_coord.dta", id(id_map) fcolor(Greens2) ///
clmethod(custom) clnumber(7) clbreaks(40 50 55 60 65 70) ndlabel(Not covered by SHFS 2016) legstyle(2) legend(position(4)) ///
ndfcolor(gs13) title("Literacy rate") subtitle("(% of population 5 years and older)") 
graph save Graph "${gsdOutput}/Map_Literacy.gph", replace


*Create map on access to improved sanitation (including IDPs)
spmap toilet using "${gsdData}/1-CleanInput/SOM_coord.dta", id(id_map) fcolor(Greens) ///
clmethod(custom) clnumber(6) clbreaks(0 5 10 15 20) ndlabel(Not covered by SHFS 2016) legstyle(2) legend(position(4)) ///
ndfcolor(gs13) title("Access to improved sanitation") subtitle("(% of households)") 
graph save Graph "${gsdOutput}/Map_Sanitation.gph", replace

