*Monetary poverty analysis for the Somali Poverty Profile 2016

set more off
set seed 23081980 
set sortseed 11041955

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

*Introduce the regional breakdown to be used for the poverty profile
use "${gsdData}/1-CleanOutput/hh.dta", clear
gen ind_profile=6 if astrata==3
replace ind_profile=5 if astrata==22
replace ind_profile=4 if astrata==21
replace ind_profile=3 if astrata==14 | astrata==15
replace ind_profile=2 if astrata==12 | astrata==13 
replace ind_profile=1 if astrata==11
label define lind_profile 1 "Mogadishu (Urban)" 2 "North-east Urban (Nugaal,Bari,Mudug)" 3 "North-west Urban (Woqooyi G,Awdal,Sanaag,Sool,Togdheer)" 4 "North-east Rural (Bari,Mudug,Nugaal)" 5 "North-west Rural (Awdal,Sanaag,Sool,Togdheer,Woqooyi)" 6 "IDP Settlements"
label values ind_profile lind_profile
label var ind_profile "Indicator: Mogadishu, North-East urban/rural, North-West urban/rural & IDPs"
keep astrata strata ea block hh ind_profile
save "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", replace

* Cross-country comparison
use "${gsdTemp}/WB_clean_all.dta", clear
merge 1:1 countryname using "${gsdData}/1-CleanInput/Country_comparison.dta", nogen
keep if country_aggr=="AFRICA" & income_cat=="L"

set obs 27
replace countryname = "SOMALI" in 27
replace countrycode = "SOM" in 27
replace poverty = 51.47 in 27
replace l_y_poverty = 2016 in 27
replace gap = 21.5 in 27
replace l_y_gap = 2016 in 27
replace gini = 37.29 in 27
replace l_y_gini = 2016 in 27
replace gdppc_c = 503.37 in 27
replace l_y_gdppc_c = 2016 in 27
replace adult_literacy_rate = 54.9 in 27
replace l_y_adult_literacy_rate =2016 in 27

replace enrollment_primary =52.9 in 27
replace l_y_enrollment_primary =2016 in 27

replace lfp =37.7 in 27
replace l_y_lfp = 2016 in 27
replace employment = 19.8 in 27
replace l_y_employment = 2016 in 27

replace attainment_primary = 15.5 in 27
replace l_y_attainment_primary = 2016 in 27
replace attainment_secondary = 6.9 in 27
replace l_y_attainment_secondary = 2016 in 27

replace improved_water = 58.0 in 27
replace l_y_improved_water = 2016 in 27

replace improved_sanitation = 10.4 in 27
replace l_y_improved_sanitation = 2016 in 27

foreach indicator in poverty gap gini remittances population lfp gdppc gdppc_c employment adult_literacy_rate enrollment_primary attainment_primary attainment_secondary improved_water improved_sanitation{
	egen avg_`indicator' = mean(`indicator')
}
order countryname countrycode poverty avg_poverty l_y_poverty gap avg_gap l_y_gap gini avg_gini l_y_gini remittances avg_remittances l_y_remittances population avg_population l_y_population lfp avg_lfp l_y_lfp gdppc avg_gdppc l_y_gdppc gdppc_c avg_gdppc_c l_y_gdppc employment avg_employment l_y_employment adult_literacy_rate avg_adult_literacy_rate l_y_adult_literacy_rate enrollment_primary avg_enrollment_primary l_y_enrollment_primary attainment_primary avg_attainment_primary l_y_attainment_primary attainment_secondary avg_attainment_secondary l_y_attainment_secondary improved_water avg_improved_water l_y_improved_water improved_sanitation avg_improved_sanitation l_y_improved_sanitation 

export excel using "${gsdOutput}/Monetary_Poverty_Figures_Final.xlsx", sheetreplace firstrow(variables) sheet("Cross-Country_Comparison_source")

* Poverty Measures

use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", nogen assert(master match) keepusing(poorPPP125_prob)

gen sub_region=6 if astrata==3
replace sub_region=5 if astrata==22
replace sub_region=3 if astrata==21
replace sub_region=4 if astrata==14 | astrata==15
replace sub_region=2 if astrata==12 | astrata==13 
replace sub_region=1 if astrata==11
label define lsub_region 1 "Mogadishu" 2 "N-E Urban" 4 "N-W Urban" 3 "N-E Rural" 5 "N-W Rural" 6 "IDP Camps"
label values sub_region lsub_region
label var sub_region "Indicator: Mogadishu, North-East urban/rural, North-West urban/rural & IDPs"
 
gen region=1 if astrata==11
replace region=2 if astrata==12 | astrata==13 | astrata==21
replace region=3 if astrata==14 | astrata==15 | astrata==22
replace region=4 if astrata==3

label define lregion 1 "Mogadishu" 2 "North-East" 3 "North-West" 4 "IDP Camps"
label values region lregion
label var region "Indicator: Mogadishu, North-East, North-West, & IDPs"
 
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata)


* Poverty Headcount ratio

*By location
qui tabout sub_region using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP_prob se lb ub) sebnone f(3) h2(Poverty headcount ratio by sub_region) replace
qui tabout region using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP_prob se lb ub) sebnone f(3) h2(Poverty headcount ratio by region) append
qui tabout type using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP_prob se lb ub) sebnone f(3) h2(Poverty headcount ratio by type of area) append

*By hhh gender
qui tabout hhh_gender using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP_prob se lb ub) sebnone f(3) h2(Poverty headcount ratio by gender of the household head) append

* Extreme Poverty Headcount ratio
qui tabout sub_region using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP125_prob se lb ub) sebnone f(3) h2(Extreme Poverty headcount ratio, by sub_region) append
qui tabout region using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP125_prob se lb ub) sebnone f(3) h2(Extreme Poverty headcount ratio, by region) append
qui tabout type using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP125_prob se lb ub) sebnone f(3) h2(Extreme Poverty headcount ratio, by type of area) append
svy: mean poorPPP125_prob if poorPPP==1 & type==3

* Poverty Gap Index
qui tabout sub_region using "${gsdOutput}/Monetary_Poverty_source.xls" if weight_cons<., svy sum c(mean pgi se lb ub) sebnone f(3) npos(col) h2(Poverty Gap, by sub_region) append
qui tabout region using "${gsdOutput}/Monetary_Poverty_source.xls" if weight_cons<., svy sum c(mean pgi se lb ub) sebnone f(3) npos(col) h2(Poverty Gap, by region) append
qui tabout type using "${gsdOutput}/Monetary_Poverty_source.xls" if weight_cons<., svy sum c(mean pgi se lb ub) sebnone f(3) npos(col) h2(Poverty Gap, by type of area) append
qui tabout hhh_gender using "${gsdOutput}/Monetary_Poverty_source.xls" if weight_cons<., svy sum c(mean pgi se lb ub) sebnone f(3) npos(col) h2(Poverty Gap, by gender of the household head) append
 
* Poverty Severity Index
qui tabout sub_region using "${gsdOutput}/Monetary_Poverty_source.xls" if weight_cons<., svy sum c(mean pseverity se lb ub) sebnone f(3) npos(col) h2(Poverty Severity, by sub_region) append
qui tabout region using "${gsdOutput}/Monetary_Poverty_source.xls" if weight_cons<., svy sum c(mean pseverity se lb ub) sebnone f(3) npos(col) h2(Poverty Severity, by region) append
qui tabout type using "${gsdOutput}/Monetary_Poverty_source.xls" if weight_cons<., svy sum c(mean pseverity se lb ub) sebnone f(3) npos(col) h2(Poverty Severity, by type of area) append
qui tabout hhh_gender using "${gsdOutput}/Monetary_Poverty_source.xls" if weight_cons<., svy sum c(mean pseverity se lb ub) sebnone f(3) npos(col) h2(Poverty Severity, by gender of the household head) append

* Vulnerable People
qui tabout region using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP_vulnerable_10_prob se lb ub) sebnone f(3) h2(Vulnerable People - Poverty headcount ratio by region and type of area) append
qui tabout type using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP_vulnerable_10_prob se lb ub) sebnone f(3) h2(Vulnerable People - Poverty headcount ratio by region and type of area) append
qui tabout region using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP_vulnerable_20_prob se lb ub) sebnone f(3) h2(Vulnerable People - Poverty headcount ratio by region and type of area) append
qui tabout type using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean poorPPP_vulnerable_20_prob se lb ub) sebnone f(3) h2(Vulnerable People - Poverty headcount ratio by region and type of area) append

* Household size and age dependency ratio
svyset ea [pweight=weight_cons], strata(strata)

qui foreach var of varlist sub_region region type {	
	tabout `var' poorPPP using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean hhsize se) sebnone cibnone f(2) h2(Household size by `var') append 
	tabout `var' poorPPP using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean age_dependency_ratio se) sebnone cibnone f(2) h2(Household Age Dependency ratio by `var') append 
}
* Household demographic attributes

qui foreach var of varlist sub_region region type {	
	tabout `var' poorPPP using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean no_children se) sebnone cibnone f(2) h2(Number of children by `var') append 
	tabout `var' poorPPP using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean no_adults se) sebnone cibnone f(2) h2(Number of adults by `var') append 
	 tabout `var' poorPPP using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean no_old_age se) sebnone cibnone f(2) h2(Number of old-age people by `var') append 
}

* Proportion of Male household heads
qui tabout sub_region using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean hhh_gender se lb ub) sebnone f(3) h2(Proportion of male-headed households by sub_region) append
qui tabout region using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean hhh_gender se lb ub) sebnone f(3) h2(Proportion of male-headed households by region) append
qui tabout type using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean hhh_gender se lb ub) sebnone f(3) h2(Proportion of male-headed households by type) append

svyset ea [pweight=pweight], strata(strata)

* Female vs. Male household head consumption
qui tabout sub_region using "${gsdOutput}/Monetary_Poverty_source.xls" if hhh_gender==0, svy sum c(mean tc_imp se lb ub) sebnone f(3) h2(Average Consumption of female-headed households by sub_region) append
qui tabout region using "${gsdOutput}/Monetary_Poverty_source.xls" if hhh_gender==0, svy sum c(mean tc_imp se lb ub) sebnone f(3) h2(Average Consumption of female-headed households by region) append
qui tabout type using "${gsdOutput}/Monetary_Poverty_source.xls" if hhh_gender==0, svy sum c(mean tc_imp se lb ub) sebnone f(3) h2(Average Consumption of female-headed households by type) append
qui tabout sub_region using "${gsdOutput}/Monetary_Poverty_source.xls" if hhh_gender==1, svy sum c(mean tc_imp se lb ub) sebnone f(3) h2(Average Consumption of male-headed households by sub_region) append
qui tabout region using "${gsdOutput}/Monetary_Poverty_source.xls" if hhh_gender==1, svy sum c(mean tc_imp se lb ub) sebnone f(3) h2(Average Consumption of male-headed households by region) append
qui tabout type using "${gsdOutput}/Monetary_Poverty_source.xls" if hhh_gender==1, svy sum c(mean tc_imp se lb ub) sebnone f(3) h2(Average Consumption of male-headed households by type) append

* Sub-regional Gini
levelsof sub_region, local(region) 
foreach i of local region {
	fastgini tc_imp [pweight=pweight] if sub_region==`i'
	return list 
	gen gini_`i'=r(gini)
    qui tabout gini_`i' using "${gsdOutput}/Monetary_Poverty_source.xls" , svy c(freq se) sebnone f(3) npos(col) h1(GINI coefficient for region `i') append
}

*Average quintile consumption, by region. Consumption Lorenz curve, at 5% distribution intervals, by region.
svyset ea [pweight=pweight], strata(strata) 
forval i=1/4 {
   xtile quintiles_tc_region`i' = tc_imp [pweight=weight_cons*hhsize] if region==`i', n(5) 
   qui tabout quintiles_tc_region`i' if region==`i' using "${gsdOutput}/Monetary_Poverty_source.xls" , svy sum c(mean tc_imp se) sebnone f(3) npos(col) h2(Total imputed consumption by quintiles (distribution within each region) in region `i') append
}
*Average quintile consumption, by type. Consumption Lorenz curve, at 5% distribution intervals, by type.
forval i=1/2 {
   xtile quintiles_tc_type`i' = tc_imp [pweight=weight_cons*hhsize] if type==`i', n(5) 
   qui tabout quintiles_tc_type`i' if type==`i' using "${gsdOutput}/Monetary_Poverty_source.xls" , svy sum c(mean tc_imp se) sebnone f(3) npos(col) h2(Total imputed consumption by quintiles (distribution within each type) in type `i') append
}
xtile quintiles_tc_country = tc_imp [pweight=weight_cons*hhsize], n(5) 
qui tabout quintiles_tc_country using "${gsdOutput}/Monetary_Poverty_source.xls" , svy sum c(mean tc_imp se) sebnone f(3) npos(col) h2(Total imputed consumption by quintiles -national) append


*Average percentile consumption, by region, at 5% distribution interval.
forval i=1/4 {
	xtile percentiles`i' = tc_imp [pweight=weight_cons*hhsize] if region==`i', n(20)
	tabout percentiles`i' if region==`i' using "${gsdOutput}/Monetary_Poverty_source.xls", svy sum c(mean tc_imp se ) sebnone f(3) npos(col) h2(Total imputed consumption by quintiles (distribution within each region) in region `i' ) append
} 

insheet using "${gsdOutput}/Monetary_Poverty_source.xls", clear nonames tab
export excel using "${gsdOutput}/Monetary_Poverty_Figures_Final.xlsx", sheetreplace firstrow(variables) sheet("Monetary_Poverty_source")
erase "${gsdOutput}/Monetary_Poverty_source.xls"

