*Multidimensional poverty analysis for the Somali Poverty Profile 2016

set more off
set seed 23081980 
set sortseed 11041955

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

use "${gsdData}/1-CleanOutput/hh.dta", clear
gen sub_region=6 if astrata==3
replace sub_region=5 if astrata==22
replace sub_region=3 if astrata==21
replace sub_region=4 if astrata==14 | astrata==15
replace sub_region=2 if astrata==12 | astrata==13 
replace sub_region=1 if astrata==11
label define lsub_region 1 "Mogadishu" 2 "N-E Urban" 4 "N-W Urban" 3 "N-E Rural" 5 "N-W Rural" 6 "IDP Camps"
label values sub_region lsub_region
label var sub_region "Indicator: Mogadishu, North-East urban/rural, North-West urban/rural & IDPs"
 
gen region=1 if astrata==11
replace region=2 if astrata==12 | astrata==13 | astrata==21
replace region=3 if astrata==14 | astrata==15 | astrata==22
replace region=4 if astrata==3

label define lregion 1 "Mogadishu" 2 "North-East" 3 "North-West" 4 "IDP Camps"
label values region lregion
label var region "Indicator: Mogadishu, North-East, North-West, & IDPs"

keep astrata strata ea block hh sub_region region
save "${gsdTemp}/PovertyNote_geographical_Breakdown.dta", replace

use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", nogen assert(master match) keepusing(astrata type weight_cons hhsize penrol_p penrol_s poorPPP house_ownership floor_material roof_material toilet_type)
merge m:1 strata ea block hh using "${gsdTemp}/PovertyNote_geographical_Breakdown.dta", nogen assert(master match) keepusing(sub_region region)

svyset ea [pweight=weight_cons], strata(strata)

*Literacy
tabout sub_region poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean literacy se lb ub) sebnone f(3) h2(Literacy rate by sub_region) replace

qui foreach var of varlist region type {	
	tabout `var' poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean literacy se lb ub) sebnone f(3) h2(Literacy rate by `var') append
}

*Educational attainment
gen complete_primary= edu_level_broad
replace complete_primary =0 if inlist(edu_level_broad,0,1,4,5,6)
replace complete_primary=1 if inlist(edu_level_broad,2)
gen complete_secondary= edu_level_broad
replace complete_secondary =0 if inlist(edu_level_broad,0,1,2,5,6)
replace complete_secondary=1 if inlist(edu_level_broad,4)
gen complete_university= edu_level_broad
replace complete_university =0 if inlist(edu_level_broad,0,1,2,4,6)
replace complete_university=1 if inlist(edu_level_broad,5)


qui foreach var of varlist complete_primary complete_secondary complete_university {
	tabout sub_region poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean `var' se lb ub) sebnone f(3) h2(`var' by sub_region) append
	tabout region poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean `var' se lb ub) sebnone f(3) h2(`var' by region) append
	tabout type poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean `var' se lb ub) sebnone f(3) h2(`var' by type) append
}

* Dwelling Quality

use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_geographical_Breakdown.dta", nogen assert(master match) keepusing(sub_region region)
svyset ea [pweight=weight_cons], strata(strata)

gen house_o_r=house_ownership
replace house_o_r=1 if inlist(house_ownership,2)
replace house_o_r=0 if inlist(house_ownership,1,3,4,1000)
label var house_o_r "Owns or rents house"

gen floor =floor_material
replace floor =1 if inlist(floor_material,2)
replace floor =0 if inlist(floor_material,1,3,4)
replace floor =. if inlist(floor_material,1000)
label var floor "The house's floor is made of tiles"

gen roof =roof_material
replace roof =1 if inlist(roof_material,2,5)
replace roof =0 if inlist(roof_material,1,3,4,6,7)
replace roof =. if inlist(roof_material,1000)
label var roof "The house's roof is made of tiles or wood"

gen toilet =toilet_type
replace toilet =1 if inlist(toilet_type,1,1000)
replace toilet =0 if inlist(toilet_type,2,3,4)

label var toilet "Access to improved sanitation"
gen pweight=weight_cons*hhsize
svyset ea [pweight=pweight], strata(strata)

gen piped_water = water
replace piped_water= 1 if inlist(water,1,2)
replace piped_water=0 if inlist(water,3,4,5)

qui foreach var of varlist house_o_r floor roof toilet piped_water{
	tabout sub_region poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean `var' se lb ub) sebnone f(3) h2(`var' by sub_region) append
	tabout region poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean `var' se lb ub) sebnone f(3) h2(`var' by region) append
	tabout type poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean `var' se lb ub) sebnone f(3) h2(`var' by type) append
}
*Labor 

*Labor Force Participation

use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", nogen assert(master match) keepusing(astrata type weight_cons hhsize penrol_p penrol_s poorPPP house_ownership floor_material roof_material toilet_type hhh_gender)
merge m:1 strata ea block hh using "${gsdTemp}/PovertyNote_geographical_Breakdown.dta", nogen assert(master match) keepusing(sub_region region)

svyset ea [pweight=weight_cons], strata(strata)

gen lfp=.
replace lfp=1 if inlist(status_7d,1,2)
replace lfp=0 if inlist(status_7d,0)
label define llfp 1 "Active" 0 "Inactive" 
label values lfp llfp
label var lfp "Labor Force Participation"

* Employment to working age population ratio

gen employment=.
replace employment=1 if inlist(status_7d,1)
replace employment=0 if inlist(status_7d,0,2)
label define lemployment 1 "Employed" 0 "Not Employed" 
label values employment lemployment
label var employment "Employment ratio, working age population"

* Unemployment to working age population ratio

gen unemployment=.
replace unemployment=1 if inlist(status_7d,2)
replace unemployment=0 if inlist(status_7d,0,1)
label define lunemployment 1 "Unemployed" 0 "Not Unemployed" 
label values unemployment lunemployment
label var unemployment "Unemployment ratio, working age population"

* Labor force participation and employment including inactive who do household work
gen lfp_hh_work= lfp
replace lfp_hh_work=1 if inac_narrow==6
gen emp_hh_work=employment
replace emp_hh_work=1 if inac_narrow==6
gen reason_inactivity_status=.c
replace reason_inactivity_status=hhm_job_search_no if status_7d==0
replace reason_inactivity_status= 1 if hhm_job_search_no == 2 & status_7d==0
*child age (6-14) enrollment
gen enrolled =0 if inrange(age,6,14)
replace enrolled =1 if inrange(age,6,14) & edu_status==1

label define lreason_inactivity_status 0 "Insecurity/conflict" 1 "Ill,sick or disabled" 3 "In school" 4 "Too young/too old to work" 5 "Retired" 6 "Taking care of own household/family" 13 "Lost/quit work" 15 "Husband would not allow" 16 "Does not expect to find work" .a "Inactive -Don't know" .b "Inactive -Refused to respond" .c "Outside Labor Force" .z "Inactive -Not administered"
label values reason_inactivity_status lreason_inactivity_status
label var reason_inactivity_status "Reason for inactivity"

qui foreach var of varlist lfp_7d employment unemployment lfp_hh_work emp_hh_work {	 
	tabout sub_region poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum percent c(mean `var' se lb ub) sebnone f(3) h2(`var' by sub_region) append
	tabout region poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum percent c(mean `var' se lb ub) sebnone f(3) h2(`var' by region) append
	tabout type poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum percent c(mean `var' se lb ub) sebnone f(3) h2(`var' by type) append
	}
qui foreach var of varlist sub_region region type {	
	tabout reason_inactivity_status `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy percent c(col) sebnone h2(Inactivity reasons -by `var') append
	tabout reason_inactivity_status `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls" if gender==0, svy percent c(col) sebnone h2(Inactivity reasons -by `var') append
    tabout reason_inactivity_status `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls" if gender==1, svy percent c(col) sebnone h2(Inactivity reasons -by `var') append
	}
qui foreach var of varlist lfp_7d employment unemployment lfp_hh_work emp_hh_work {	
	tabout sub_region gender using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum percent c(mean `var') sebnone f(3) h2(`var' by sub_region) append
	tabout region gender using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum percent c(mean `var') sebnone f(3) h2(`var' by region) append
	tabout type gender using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum percent c(mean `var') sebnone f(3) h2(`var' by type) append
	}	

*Net School enrollment age among children aged (6-14)
 
qui foreach var of varlist sub_region region type {	
	tabout `var' gender using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean enrolled) sebnone f(3) h2(enrolled by `var') append
}
qui foreach var of varlist sub_region region type {	
	tabout `var' poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean enrolled) sebnone f(3) h2(enrolled by `var') append
}
qui foreach var of varlist sub_region region type {	
	tabout `var' hhh_gender using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy sum c(mean enrolled) sebnone f(3) h2(enrolled by `var') append
}
*Health - Birth delivery
qui foreach var of varlist sub_region region type {	
	tabout delivery `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy percent c(col) sebnone h2(birth delivery -by `var') append
    tabout delivery `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls" if poorPPP==1, svy percent c(col) sebnone h2(birth delivery, poor -by `var') append
	tabout delivery `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls" if poorPPP==0, svy percent c(col) sebnone h2(birth delivery, non-poor -by `var') append
}
*Healthcare - Expenditures 
use "${gsdData}/1-CleanOutput/nonfood.dta", clear 
keep if itemid==1081
merge 1:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", keep(match) keepusing(hhh_gender poorPPP quintiles_tc weight_cons) nogen
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_geographical_Breakdown.dta", nogen keep(match) keepusing(sub_region region)

gen healthcare_exp = purc_usd_imp*52/hhsize
la var healthcare_exp "Mean annual health expenses per person, current USD"
svyset ea [pweight=weight_cons], strata(strata)
qui foreach var of varlist sub_region region type {	 
	tabout `var' poorPPP using "${gsdOutput}/Multidimensional_Poverty_source.xls" , svy sum c(mean healthcare_exp se) ci2col sebnone f(3) h2(Mean annual health expenses per person, current USD) append 
}
*Roof and Floor 
use "${gsdData}/1-CleanOutput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_geographical_Breakdown.dta", nogen assert(master match) keepusing(sub_region region)
svyset ea [pweight=weight_cons], strata(strata)

qui foreach var of varlist sub_region region type {	
	tabout roof_material `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy percent c(col) sebnone h2(Roof material -by `var') append
    tabout roof_material `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls" if poorPPP==1, svy percent c(col) sebnone h2(Roof material, poor -by `var') append
	tabout roof_material `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls" if poorPPP==0, svy percent c(col) sebnone h2(Roof material, non-poor -by `var') append
}
qui foreach var of varlist sub_region region type {	
	tabout floor_material `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy percent c(col) sebnone h2(Floor material -by `var') append
    tabout floor_material `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls" if poorPPP==1, svy percent c(col) sebnone h2(Floor material, poor -by `var') append
	tabout floor_material `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls" if poorPPP==0, svy percent c(col) sebnone h2(Floor material, non-poor -by `var') append
}



*Create the dimensions for the multidimensional analysis

*Education - at least one chile in primary age not in school (by urban/rural status, hhh gender and remittances)
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
gen count = (hhm_edu_current==0 & inrange(age, 6, 13))
collapse (max) primaryage_notinschool=count, by(strata ea block hh ind_profile)
la def lprimaryage_notinschool 0 "All children of primary school age enrolled" 1 "At least one child of primary school age not enrolled" 
la val primaryage_notinschool lprimaryage_notinschool
merge 1:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(poorPPP quintiles_tc hhh_gender weight_cons remit12m) nogen
svyset ea [pweight=weight_cons], strata(strata)
save "${gsdTemp}/mpoverty_edu.dta", replace

*Water - household does not have access to improved water source (by urban/rural status, hhh gender and remittances)
use "${gsdData}/1-CleanOutput/hh.dta", clear 
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen assert(match)
svyset ea [pweight=weight_cons], strata(strata)
gen water_improved=1 if water==1 | water==2
replace water_improved=0 if water_improved==.
label define lwater_improved 1 "Has access to improved sources" 0 "Does not have access"
label values water_improved lwater_improved

*Sanitation - households does not have access to improved saniation (by urban/rural status, hhh gender and remittances)
gen sanitation_improved=1 if toilet_type==1 | toilet_type==2
replace sanitation_improved=0 if sanitation_improved==.
label define lsanitation_improved 1 "Has access to improved sources" 0 "Does not have access"
label values sanitation_improved lsanitation_improved
save "${gsdTemp}/mpoverty_water_sanitation.dta", replace

*Information - household does not have radio, tv or computer  (by urban/rural status, hhh gender and remittances)
use "${gsdData}/1-CleanOutput/assets.dta", clear 
merge m:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen keep(match)
keep if itemid==26 | itemid==28 |  itemid==30 | itemid==31
gen access_info=1 
collapse (max) access_info, by(strata ea block hh ind_profile)
merge 1:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", keep(match using) keepusing(hhh_gender poorPPP quintiles_tc weight_cons) nogen
replace access_info=0 if access_info==.
la var access_info "The household owns a radio, tv or computer"
label define laccess_info 1 "Owns radio, tv and/or computer" 0 "Does not own"
label values access_info laccess_info
svyset ea [pweight=weight_cons], strata(strata)
drop ind_profile
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_Regional_Breakdown.dta", nogen keep(match)
save "${gsdTemp}/mpoverty_info.dta", replace


*Multidimensional poverty. 
use "${gsdTemp}/mpoverty_water_sanitation.dta", clear
merge 1:1 strata ea block hh using "${gsdTemp}/mpoverty_edu.dta", assert(match) keep(match) keepusing(primaryage_notinschool) nogen
merge 1:1 strata ea block hh using "${gsdTemp}/mpoverty_info.dta", assert(match) keep(match) keepusing(access_info) nogen
merge 1:1 strata ea block hh using "${gsdTemp}/PovertyNote_geographical_Breakdown.dta", nogen assert(match) keepusing(sub_region region)

gen pweight=weight_cons*hhsize
svyset ea [pweight=weight_cons], strata(strata)


*Analysis by each dimension
qui foreach var of varlist poorPPP primaryage_notinschool water_improved access_info  {	
    tabout `var' sub_region using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy percent c(col) sebnone h2(Deprivation in multiple dimensions -by ind_profile) append
}
qui foreach var of varlist poorPPP primaryage_notinschool water_improved access_info  {	
    tabout `var' region using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy percent c(col) sebnone h2(Deprivation in multiple dimensions -by region) append
}
qui foreach var of varlist poorPPP primaryage_notinschool water_improved access_info  {	
    tabout `var' type using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy percent c(col) sebnone h2(Deprivation in multiple dimensions -by type) append
}
 

*Households deprive in n least i dimensions
gen depr_n= (primaryage_notinschool==1) + (water_improved==0) + (access_info==0)

qui foreach var of varlist sub_region region type {	
	tabout depr_n `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy percent c(col) sebnone h2(Deprivation in multiple dimensions -by `var') append
    tabout depr_n `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls" if poorPPP==1, svy percent c(col) sebnone h2(Deprivation in multiple dimensions, poor -by `var') append
	tabout depr_n `var' using "${gsdOutput}/Multidimensional_Poverty_source.xls" if poorPPP==0, svy percent c(col) sebnone h2(Deprivation in multiple dimensions, non-poor -by `var') append
}  
drop depr_n

*Households deprive at least in i dimensions
gen depr_n= poorPPP + (primaryage_notinschool==1) + (water_improved==0) + (access_info==0)
forvalues i=1/4 {
 gen depr_al`i' = depr_n>=`i' if !missing(depr_n)
 tabout depr_al`i' sub_region using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy percent c(col) sebnone f(3) h1(Deprivation in `i' dimension ) append
}
drop depr_*
gen depr_n= poorPPP + (primaryage_notinschool==1) + (water_improved==0) + (access_info==0)
forvalues i=1/4 {
 gen depr_al`i' = depr_n>=`i' if !missing(depr_n)
 tabout depr_al`i' type using "${gsdOutput}/Multidimensional_Poverty_source.xls", svy percent c(col) sebnone f(3) h1(Deprivation in `i' dimension ) append
}





*Integrate the data 
insheet using "${gsdOutput}/Multidimensional_Poverty_source.xls", clear nonames tab
export excel using "${gsdOutput}/Multidimensional_Poverty_Figures_Final.xlsx", sheetreplace firstrow(variables) sheet("Multidimensional_Poverty_source")
erase "${gsdOutput}/Multidimensional_Poverty_source.xls"
