*Comparison of the North West region 2013 vs. 2016 for the Somali Poverty Profile 2016

set more off
set seed 23081580 
set sortseed 11041585

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

*Check if the relevant files from the pipeline for SLHS 2013 have been saved in 1-CleanInput from Wave 1 of SHFS 2016
foreach dataset in "hh" "hhm" "food_consumption_clean" "paasche_r" "paasche_u" {
	capture confirm file "${gsdData}/1-CleanInput/SLHS13/`dataset'.dta"
	if _rc==0 {
		display "No action needed"
    }
	else {
    display as error "Please include the files from SLHS 2013 first"
	error `dataset'
	}

}

  
*Implicit scale factor between total consumption and comparable consumption 
use "${gsdData}/1-CleanTemp/hhq-poverty_comparable_2013.dta", clear
keep strata ea block hh weight_cons hhsize hhweight team tc_imp
rename tc_imp tc_imp_comparable
merge 1:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", nogen keep(match master) keepusing(type tc_imp)
rename tc_imp tc_imp_tot
svyset ea [pweight=hhweight], strata(strata)
*North West
sum tc_imp_tot [aweight=hhweight] if team==1 & (type==1 | type==2), d
gen mean_cons_tot_sld=r(mean)
sum tc_imp_comparable [aweight=hhweight] if team==1 & (type==1 | type==2), d
gen mean_cons_comparable_sld=r(mean)
gen scale_factor_sld=mean_cons_comparable_sld/mean_cons_tot_sld
*Urban
sum tc_imp_tot [aweight=hhweight] if team==1 & type==1, d
gen mean_cons_tot_urban=r(mean)
sum tc_imp_comparable [aweight=hhweight] if team==1 & type==1, d
gen mean_cons_comparable_urban=r(mean)
gen scale_factor_urban=mean_cons_comparable_urban/mean_cons_tot_urban
qui tabout mean_cons_tot_urban using "${gsdOutput}/Somaliland_Comparison_0.xls" , svy c(freq se) sebnone f(3) npos(col) h1(mean_cons_tot_urban) replace
foreach measure in "mean_cons_comparable_urban" "scale_factor_urban" {
qui tabout `measure' using "${gsdOutput}/Somaliland_Comparison_0.xls" , svy c(freq se) sebnone f(3) npos(col) h1(`measure') append
}
*Rural
sum tc_imp_tot [aweight=hhweight] if team==1 & type==2, d
gen mean_cons_tot_rural=r(mean)
sum tc_imp_comparable [aweight=hhweight] if team==1 & type==2, d
gen mean_cons_comparable_rural=r(mean)
gen scale_factor_rural=mean_cons_comparable_rural/mean_cons_tot_rural
foreach measure in "mean_cons_tot_rural" "mean_cons_comparable_rural" "scale_factor_rural" {
qui tabout `measure' using "${gsdOutput}/Somaliland_Comparison_0.xls" , svy c(freq se) sebnone f(3) npos(col) h1(`measure') append
}
keep type scale_factor_sld scale_factor_urban scale_factor_rural
bys type: keep if _n==1
save "${gsdTemp}/scale_factor_sld_2013vs2016.dta", replace


*Poverty headcount 2016 (total consumption and normal poverty line)
use "${gsdData}/1-CleanOutput/hh.dta", clear
gen hhweight=hhsize*weight_cons
svyset ea [pweight=hhweight], strata(strata)
drop poorPPP
*Estimate poverty in the same way for every survey and with the same households 
drop if ( strata==101 & ea==104 & block==25 & hh==10 ) | ( strata==101 & ea==303 & block==23 & hh==6 ) | ( strata==101 & ea==317 & block==10 & hh==6 )
gen poorPPP=tc_imp<plinePPP if !mi(tc_imp)
qui tabout type using "${gsdOutput}/Somaliland_Comparison_1.xls" if team==1 & (type==1 | type==2), svy sum c(mean poorPPP se) sebnone f(3) h2(Poverty headcount ratio - 2016 (Total consumption + normal poverty line)) replace
qui tabout remit12m type using "${gsdOutput}/Somaliland_Comparison_1.xls" if team==1 & (type==1 | type==2), svy sum c(mean poorPPP se) sebnone f(3) h1(Poverty headcount ratio by remittances - 2016 (Total consumption + normal poverty line)) append

*Poverty headcount 2016 (comparable consumption and scaled poverty line)
use "${gsdData}/1-CleanTemp/hhq-poverty_comparable_2013.dta", clear
keep strata ea block hh weight_cons hhsize hhweight team tc_imp
merge 1:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", nogen keep(match master) keepusing(type plinePPP remit12m)
merge m:1 type using "${gsdTemp}/scale_factor_sld_2013vs2016.dta", nogen assert(match master) 
gen scaled_plinePPP=plinePPP*scale_factor_sld if type==3
replace scaled_plinePPP=plinePPP*scale_factor_urban if type==1
replace scaled_plinePPP=plinePPP*scale_factor_rural if type==2
gen poorPPP=tc_imp<scaled_plinePPP if !mi(tc_imp)
svyset ea [pweight=hhweight], strata(strata)
qui tabout type using "${gsdOutput}/Somaliland_Comparison_1.xls" if team==1 & (type==1 | type==2), svy sum c(mean poorPPP se) sebnone f(3) h2(Poverty headcount ratio - 2016 (Comparable consumption + scaled poverty line)) append
qui tabout remit12m type using "${gsdOutput}/Somaliland_Comparison_1.xls" if team==1 & (type==1 | type==2), svy sum c(mean poorPPP se) sebnone f(3) h1(Poverty headcount ratio by remittances - 2016 (Comparable consumption + scaled poverty line)) append
save "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", replace

*Poverty headcount 2013 (comparable consumption and scaled poverty line)
use "${gsdData}/1-CleanInput/SLHS13/hh.dta", clear
gen type=urban 
replace type=2 if type==0 
merge m:1 type using "${gsdTemp}/scale_factor_sld_2013vs2016.dta", nogen keep(match) 
gen hhweight=weight*S1_HHSIZE
svyset cluster [pweight=hhweight], strata(strata)
*Convert consumption to real per capita per day 
gen cons_aggr=(rpce*1000*12)/365
*Define the poverty line 
*in 2011, $1 USD PPP was worth 10,731 Somali Shillings PPP, & general inflation in Somaliland from 2011 to 2013 was 58.4%
*so 16,996.43 Somali Shillings PPP (2013 Somaliland prices) could buy $1 USD PPP (2011)
*thus $1.90 USD PPP 2011 corresponds to 32,293.22 Somali Shillings PPP
*then we convert to USD using an average exchange rate of 20,360.53 Somali Shillings per USD in 2013, that is $1.5861 USD PPP (2013 Somaliland prices)
*to finally convert to Somaliland Shillings using an average exchange rate of 6,733.69 Somaliland Shillings per USD in 2013, which gives us a poverty line of 10,680.11 Somaliland Shillings PPP (2013 Somaliland prices) per person per day, equivalent to $1.90 USD PPP (2011) 
gen plinePPP=10680.1112312
gen scaled_plinePPP=plinePPP*scale_factor_urban if type==1
replace scaled_plinePPP=plinePPP*scale_factor_rural if type==2
*Define poor and non-poor households in the same way as 2016
gen poorPPP = cons_aggr < scaled_plinePPP 
qui tabout urban using "${gsdOutput}/Somaliland_Comparison_1.xls", svy sum c(mean poorPPP se) sebnone f(3) h2(Poverty headcount ratio - 2013 (Comparable consumption + scaled poverty line)) append
merge 1:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen keep(master match) keepusing(S4_J03C107 S4_J03C_U107 S4_J03C108 S4_J03C_U108)
*Include remittances
gen dummy_remitt=0 if rremitpc==0
replace dummy_remitt=1 if rremitpc>0
qui tabout dummy_remitt urban using "${gsdOutput}/Somaliland_Comparison_1.xls", svy sum c(mean poorPPP se) sebnone f(3) h1(Poverty headcount ratio by remittances - 2013 (Comparable consumption + scaled poverty line)) append
save "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", replace


*Poverty gap 2016
use "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", clear
svyset ea [pweight=hhweight], strata(strata)
gen pgi = (scaled_plinePPP - tc_imp)/scaled_plinePPP if !mi(tc_imp) & tc_imp < scaled_plinePPP
replace pgi = 0 if tc_imp>scaled_plinePPP & !mi(tc_imp)
qui tabout type using "${gsdOutput}/Somaliland_Comparison_1.xls" if team==1 & (type==1 | type==2), svy sum c(mean pgi se) sebnone f(3) h2(Poverty gap - 2016) append


*Poverty gap 2013 
use "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", clear
svyset cluster [pweight=hhweight], strata(strata)
gen pgi = (scaled_plinePPP - cons_aggr)/scaled_plinePPP if !mi(cons_aggr) & cons_aggr < scaled_plinePPP
replace pgi = 0 if cons_aggr>scaled_plinePPP & !mi(cons_aggr)
qui tabout urban using "${gsdOutput}/Somaliland_Comparison_1.xls", svy sum c(mean pgi se) sebnone f(3) h1(Poverty gap - 2013) append


*Inequality 2016
use "${gsdData}/1-CleanOutput/hh.dta", clear 
gen hhweight = weight_cons * hhsize
svyset ea [pweight=hhweight], strata(strata) 
*Obtain comparable consumption
drop tc_imp
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty_comparable_2013.dta", nogen keep(match) keepusing(tc_imp)
fastgini tc_imp [pweight=hhweight] if team==1 & type==1
return list 
gen gini_16_urban=r(gini)
qui tabout gini_16_urban using "${gsdOutput}/Somaliland_Comparison_1.xls" , svy c(freq se) sebnone f(3) npos(col) h1(GINI coefficient - 2016 Urban) append
fastgini tc_imp [pweight=hhweight] if team==1 & type==2
return list 
gen gini_16_rural=r(gini)
qui tabout gini_16_rural using "${gsdOutput}/Somaliland_Comparison_1.xls" , svy c(freq se) sebnone f(3) npos(col) h1(GINI coefficient - 2016 Rural) append


*Inequality 2013
use "${gsdData}/1-CleanInput/SLHS13/hh.dta", clear
gen hhweight=weight*S1_HHSIZE
svyset cluster [pweight=hhweight], strata(strata)
gen cons_aggr=(rpce*1000*12)/365 
fastgini cons_aggr [pweight=hhweight] if urban==1
return list 
gen gini_12_urban=r(gini)
qui tabout gini_12_urban using "${gsdOutput}/Somaliland_Comparison_1.xls" , svy c(freq se) sebnone f(3) npos(col) h1(GINI coefficient - 2013 Urban) append
fastgini cons_aggr [pweight=hhweight] if urban==0
return list 
gen gini_12_rural=r(gini)
qui tabout gini_12_rural using "${gsdOutput}/Somaliland_Comparison_1.xls" , svy c(freq se) sebnone f(3) npos(col) h1(GINI coefficient - 2013 Rural) append


*2016 and 2013: No. of observations needed for the t-test of poverty indicators
use "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", clear
qui tabout type using "${gsdOutput}/Somaliland_Comparison_1.xls" if !missing(poorPPP) & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h2(Sample size 2016 - Poverty indicators) append
qui tabout type remit12m using "${gsdOutput}/Somaliland_Comparison_1.xls" if !missing(poorPPP) & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h2(Sample size 2016 - Poverty indicators w/remittances) append
use "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", clear
qui tabout urban using "${gsdOutput}/Somaliland_Comparison_1.xls" if !missing(poorPPP), c(freq) f(3) npos(col) h1(Sample size 2013 - Poverty indicators) append
qui tabout urban dummy_remitt using "${gsdOutput}/Somaliland_Comparison_1.xls" if !missing(poorPPP), c(freq) f(3) npos(col) h1(Sample size 2013 - Poverty indicators w/remittances) append


*Consumption distribution 2016 (Total consumption)
use "${gsdData}/1-CleanOutput/hh.dta", clear 
gen hhweight = weight_cons * hhsize
svyset ea [pweight=hhweight], strata(strata) 
*Obtain comparable consumption
drop tc_imp
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty_comparable_2013.dta", nogen keep(match) keepusing(tc_imp)
*Convert consumption into 2011 PPP
gen zone=3
merge m:1 zone using "${gsdData}/1-CleanInput/HFS Exchange Rate Survey.dta", nogen keepusing(global_er) keep(match master) 
merge m:1 zone using "${gsdData}/1-CleanTemp/inflation.dta", nogen keepusing(gg) assert(match using) keep(match)
gen rate_ppp=10731
gen tc_imp_2011_ppp=((tc_imp*global_er)/gg)/rate_ppp
xtile percentiles_tc_urban = tc_imp_2011_ppp [pweight=hhweight] if team==1 & type==1, n(100)
qui tabout percentiles_tc_urban using "${gsdOutput}/Somaliland_Comparison_2.xls" , svy sum c(mean tc_imp_2011_ppp) sebnone f(3) npos(col) h2(Total imputed consumption - 2016 & Urban) replace
xtile percentiles_tc_rural = tc_imp_2011_ppp [pweight=hhweight] if team==1 & type==2, n(100)
qui tabout percentiles_tc_rural using "${gsdOutput}/Somaliland_Comparison_2.xls" , svy sum c(mean tc_imp_2011_ppp) sebnone f(3) npos(col) h2(Total imputed consumption - 2016 & Rural) append

*Consumption distribution 2013 (Total consumption)
use "${gsdData}/1-CleanInput/SLHS13/hh.dta", clear
gen hhweight=weight*S1_HHSIZE
svyset cluster [pweight=hhweight], strata(strata)
gen cons_aggr=(rpce*1000*12)/365 
*Convert consumption into 2011 PPP
gen cons_aggr_2011_PPP=(((cons_aggr/6733.69)*20360.53)/1.584)/10731
xtile percentiles_tc_urban = cons_aggr_2011_PPP [pweight=hhweight] if urban==1, n(100)
qui tabout percentiles_tc_urban using "${gsdOutput}/Somaliland_Comparison_2.xls" , svy sum c(mean cons_aggr_2011_PPP) sebnone f(3) npos(col) h2(Total imputed consumption - 2013 & Urban) append
xtile percentiles_tc_rural = cons_aggr_2011_PPP [pweight=hhweight] if urban==0, n(100)
qui tabout percentiles_tc_rural using "${gsdOutput}/Somaliland_Comparison_2.xls" , svy sum c(mean cons_aggr_2011_PPP) sebnone f(3) npos(col) h2(Total imputed consumption - 2013 & Rural) append


*Consumption distribution 2016 (Core food)
use "${gsdData}/1-CleanOutput/food.dta", clear 
keep if mod_item==0
*Obtain comparable consumption
drop if itemid==46 | (itemid>=103 & itemid<=122)
drop if ( strata==101 & ea==104 & block==25 & hh==10 ) | ( strata==101 & ea==303 & block==23 & hh==6 ) | ( strata==101 & ea==317 & block==10 & hh==6 )
collapse (sum) cons_usd_imp, by(strata ea block hh weight_cons hhsize)
gen hhweight = weight_cons * hhsize
svyset ea [pweight=hhweight], strata(strata) 
replace cons_usd_imp=(cons_usd_imp/7)/hhsize
*Convert consumption into 2011 PPP
gen zone=3
merge m:1 zone using "${gsdData}/1-CleanInput/HFS Exchange Rate Survey.dta", nogen keepusing(global_er) keep(match master) 
merge m:1 zone using "${gsdData}/1-CleanTemp/inflation.dta", nogen keepusing(gg) assert(match using) keep(match)
merge 1:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", nogen keepusing(team type) assert(match using) keep(match)
gen rate_ppp=10731
gen cons_usd_2011_ppp=((cons_usd_imp*global_er)/gg)/rate_ppp
xtile percentiles_tc_urban = cons_usd_2011_ppp [pweight=hhweight] if team==1 & type==1, n(100)
qui tabout percentiles_tc_urban using "${gsdOutput}/Somaliland_Comparison_2.xls" , svy sum c(mean cons_usd_2011_ppp) sebnone f(3) npos(col) h2(Core food consumption - 2016 & Urban) append
xtile percentiles_tc_rural = cons_usd_2011_ppp [pweight=hhweight] if team==1 & type==2, n(100)
qui tabout percentiles_tc_rural using "${gsdOutput}/Somaliland_Comparison_2.xls" , svy sum c(mean cons_usd_2011_ppp) sebnone f(3) npos(col) h2(Core food consumption - 2016 & Rural) append


*Consumption distribution 2013 (Core food)
use "${gsdData}/1-CleanInput/SLHS13/food_consumption_clean.dta", clear
*items in the core group
keep if foodid==102 | foodid==105 | foodid==107 | foodid==109 | foodid==113 | foodid==115 | foodid==118 | foodid==119 | foodid==201 | foodid==306 | foodid==307 | foodid==310 | foodid==401 | foodid==402 | foodid==403 | foodid==404 | foodid==407 | foodid==410 | foodid==501 | foodid==502 | foodid==513 | foodid==601 | foodid==704 | foodid==705 | foodid==706 | foodid==802 | foodid==805 | foodid==807 | foodid==813 | foodid==901 | foodid==905 | foodid==907 | foodid==909 | foodid==916
collapse (sum) x* (firstnm) weight district region strata cluster, by(hhid)
merge 1:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", keepusing(urban) assert(match) nogen
merge m:1 district urban using "${gsdData}/1-CleanInput/SLHS13/paasche_r.dta", keepusing(paasche_r) nogen
merge m:1 district urban using "${gsdData}/1-CleanInput/SLHS13/paasche_u.dta", keepusing(paasche_u) nogen
gen paasche = . 
replace paasche = paasche_u if urban == 1 
replace paasche = paasche_r if urban == 0
drop paasche_r paasche_u
*include hhsize 
merge 1:m hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", keepusing(S1_HHSIZE) nogen keep(match)
gen cons_usd=(((xfood/paasche)/S1_HHSIZE)*1000*12)/365
gen hhweight=weight*S1_HHSIZE
svyset cluster [pweight=hhweight], strata(strata)
*Convert consumption into 2011 PPP
gen cons_usd_2011_PPP=(((cons_usd/6733.69)*20360.53)/1.584)/10731
xtile percentiles_tc_urban = cons_usd_2011_PPP [pweight=hhweight] if urban==1, n(100)
qui tabout percentiles_tc_urban using "${gsdOutput}/Somaliland_Comparison_2.xls" , svy sum c(mean cons_usd_2011_PPP) sebnone f(3) npos(col) h2(Core food consumption - 2013 & Urban) append
xtile percentiles_tc_rural = cons_usd_2011_PPP [pweight=hhweight] if urban==0, n(100)
qui tabout percentiles_tc_rural using "${gsdOutput}/Somaliland_Comparison_2.xls" , svy sum c(mean cons_usd_2011_PPP) sebnone f(3) npos(col) h2(Core food consumption - 2013 & Rural) append


*Remittances 2016
use "${gsdData}/1-CleanOutput/hh.dta", clear
svyset ea [pweight=weight_cons], strata(strata)
drop poorPPP
merge 1:1 strata ea block hh using "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", nogen keep(match) keepusing(poorPPP)
qui tabout remit12m poorPPP if team==1 & type==1 using "${gsdOutput}/Somaliland_Comparison_3.xls", svy percent c(col se) sebnone npos(col) h1(Remittances & poverty - 2016 Urban) replace
qui tabout remit12m poorPPP if team==1 & type==2 using "${gsdOutput}/Somaliland_Comparison_3.xls", svy percent c(col se) sebnone npos(col) h1(Remittances & poverty - 2016 Rural) append


*Remittances 2013
use "${gsdData}/1-CleanInput/SLHS13/hh.dta", clear
drop rremitpc
gen remit1 = S4_J03C107 * 1000^(S4_J03C_U107-1)
gen remit2 = S4_J03C108 * 1000^(S4_J03C_U108-1)
gen remit = 0
replace remit = remit + remit1 if remit1<.
replace remit = remit + remit2 if remit2<.
replace remit = remit/1000
gen rremitpc = remit/paasche / S1_HHSIZE / 12
label var rremitpc "Real remittance per capita per month"
gen dummy_remitt=0 if rremitpc==0
replace dummy_remitt=1 if rremitpc>0
merge 1:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
svyset cluster [pweight=weight], strata(strata)
qui tabout dummy_remitt poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if urban==1, svy percent c(col se) sebnone npos(col) h1(Remittances & poverty - 2013 Urban) append
qui tabout dummy_remitt poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if urban==0, svy percent c(col se) sebnone npos(col) h1(Remittances & poverty - 2013 Rural) append


*Household size 2016
use "${gsdData}/1-CleanOutput/hh.dta", clear
svyset ea [pweight=weight_cons], strata(strata)
drop poorPPP
merge 1:1 strata ea block hh using "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", nogen keep(match) keepusing(poorPPP)
qui tabout type poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & (type==1 | type==2), svy sum c(mean hhsize se) sebnone f(3) h1(Households Size by type & poor - 2016) append


*Household size 2013 
use "${gsdData}/1-CleanInput/SLHS13/hh.dta", clear
svyset cluster [pweight=weight], strata(strata)
merge 1:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
qui tabout urban poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls", svy sum c(mean S1_HHSIZE se) sebnone f(3) h1(Household size by type & poor - 2013) append


*Gender of household head 2016
use "${gsdData}/1-CleanOutput/hh.dta", clear
drop poorPPP
merge 1:1 strata ea block hh using "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", nogen keep(match) keepusing(poorPPP)
svyset ea [pweight=weight_cons], strata(strata)
qui tabout hhh_gender poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & type==1, svy percent c(col se) sebnone npos(col) h1(Gender of hhh & poverty - 2016 Urban) append
qui tabout hhh_gender poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & type==2, svy percent c(col se) sebnone npos(col) h1(Gender of hhh & poverty - 2016 Rural) append


*Gender of household head 2013
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
gen pre_hhh_female=1 if S3_A05==1 & S3_A04==2
replace pre_hhh_female=0 if pre_hhh_female==.
bys hhid: egen hhh_female=max(pre_hhh_female)
merge m:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen assert(match) keepusing(cluster strata)
collapse (max) hhh_female, by( hhid weight cluster strata urban)
svyset cluster [pweight=weight], strata(strata)
merge 1:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
qui tabout hhh_female poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if urban==1, svy percent c(col se) sebnone npos(col) h1(Gender of hhh - 2013 Urban) append
qui tabout hhh_female poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if urban==0, svy percent c(col se) sebnone npos(col) h1(Gender of hhh - 2013 Rural) append


*Population pyramid 2016
use "${gsdData}/1-CleanOutput/hhm.dta", clear 
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons type) nogen
svyset ea [pweight=weight_cons], strata(strata)
qui tabout age_cat_narrow gender using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & type==1, svy pop c(freq se) f(3) sebnone h1(Age distribution (5-year intervals) by gender - Urban) append
qui tabout age_cat_narrow gender using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & type==2, svy pop c(freq se) f(3) sebnone h1(Age distribution (5-year intervals) by gender - Rural) append


*Population pyramid 2013
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
merge m:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen assert(match) keepusing(cluster strata)
svyset cluster [pweight=weight], strata(strata)
qui tabout S3_AGE_5 S3_A04 using "${gsdOutput}/Somaliland_Comparison_3.xls" if urban==1, svy pop c(freq se) f(3) sebnone h1(Age distribution (5-year intervals) by gender - Urban) append
qui tabout S3_AGE_5 S3_A04 using "${gsdOutput}/Somaliland_Comparison_3.xls" if urban==0, svy pop c(freq se) f(3) sebnone h1(Age distribution (5-year intervals) by gender - Rural) append


*Literacy rate 2016
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", nogen keep(match master) keepusing(poorPPP)
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons type) nogen
svyset ea [pweight=weight_cons], strata(strata)
qui tabout literacy poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & type==1, svy percent c(col se) npos(col) sebnone cibnone h1(Literacy - 2016 Urban) append
qui tabout literacy poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & type==2, svy percent c(col se) npos(col) sebnone cibnone h1(Literacy - 2016 Rural) append


*Literacy rate 2013
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
merge m:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen assert(match) keepusing(cluster strata)
svyset cluster [pweight=weight], strata(strata)
merge m:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
qui tabout lit_any poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if urban==1, svy percent c(col se) npos(col) sebnone cibnone h1(Literacy - 2013 Urban) append
qui tabout lit_any poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if urban==0, svy percent c(col se) npos(col) sebnone cibnone h1(Literacy - 2013 Rural) append


*Percentage in labor force 2016 
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons type team) nogen
merge m:1 strata ea block hh using "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", nogen keep(match master) keepusing(poorPPP)
svyset ea [pweight=weight_cons], strata(strata)
qui tabout lfp_7d poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if working_age==1 & team==1 & type==1, svy percent c(col se) npos(col) sebnone h1(Labor force participation (%) - 2016 Urban) append
qui tabout lfp_7d poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if working_age==1 & team==1 & type==2, svy percent c(col se) npos(col) sebnone h1(Labor force participation (%) - 2016 Rural) append


*Percentage in labor force 2013
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
merge m:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen assert(match) keepusing(cluster strata)
merge m:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
svyset cluster [pweight=weight], strata(strata)
qui tabout lfp poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if urban==1, svy percent c(col se) npos(col) sebnone h1(Labor force participation (%) - 2013 Urban) append
qui tabout lfp poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if urban==0, svy percent c(col se) npos(col) sebnone h1(Labor force participation (%) - 2013 Rural) append


*Value of remittances 2016 
use "${gsdData}/1-CleanOutput/hh.dta", clear 
svyset ea [pweight=weight_cons], strata(strata) 
*Convert remittances into 2011 PPP
gen zone=3
merge m:1 zone using "${gsdData}/1-CleanInput/HFS Exchange Rate Survey.dta", nogen keepusing(global_er) keep(match master) 
merge m:1 zone using "${gsdData}/1-CleanTemp/inflation.dta", nogen keepusing(gg) assert(match using) keep(match)
merge m:1 astrata using "${gsdData}/1-CleanTemp/food-deflator.dta", nogen assert(match) keep(match) keepusing(deflator)
replace remit12m_usd=remit12m_usd/deflator
gen rate_ppp=10731
gen remitt_2011_ppp=(((remit12m_usd*global_er)/gg)/rate_ppp)/hhsize
drop poorPPP
merge 1:1 strata ea block hh using "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", nogen keep(match) keepusing(poorPPP)
qui tabout type poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & (type==1 | type==2), svy sum c(mean remitt_2011_ppp se) sebnone f(3) h1(Value of remittances by type & poor- 2016) append


*Value of remittances 2013
use "${gsdData}/1-CleanInput/SLHS13/hh.dta", clear
svyset cluster [pweight=weight], strata(strata)
gen remit1 = S4_J03C107 * 1000^(S4_J03C_U107-1)
gen remit2 = S4_J03C108 * 1000^(S4_J03C_U108-1)
gen remit =0
replace remit = remit + remit1 if remit1<.
replace remit = remit + remit2 if remit2<.
replace remit= remit/paasche 
replace remit=. if remit==0
label var remit "Annual remittance per hh in SLD Shilling"
*Convert consumption into 2011 PPP
gen remitt_2011_ppp=((((remit/6733.69)*20360.53)/1.584)/10731)/S1_HHSIZE
merge 1:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
qui tabout urban poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls", svy sum c(mean remitt_2011_ppp se) sebnone f(3) h1(Value of remittances by type & poor - 2013) append


*Migration 2016 
use "${gsdData}/1-CleanOutput/hhm.dta", clear 
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons type) nogen
svyset ea [pweight=weight_cons], strata(strata)
qui tabout hh_alwayslived gender using "${gsdOutput}/Somaliland_Comparison_3.xls" if age>=25 & team==1 & type==1, svy percent c(col se) npos(col) sebnone h1(Migration and gender - 2016 Urban) append
qui tabout hh_alwayslived gender using "${gsdOutput}/Somaliland_Comparison_3.xls" if age>=25 & team==1 & type==2, svy percent c(col se) npos(col) sebnone h1(Migration and gender - 2016 Rural) append


*Migration 2013
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
svyset cluster [pweight=weight], strata(strata)
qui tabout S3_AB02 S3_A04 using "${gsdOutput}/Somaliland_Comparison_3.xls" if S3_AGE_5>=6 & urban==1, svy percent c(col se) npos(col) sebnone h1(Migration and gender - 2013 Urban) append
qui tabout S3_AB02 S3_A04 using "${gsdOutput}/Somaliland_Comparison_3.xls" if S3_AGE_5>=6 & urban==0, svy percent c(col se) npos(col) sebnone h1(Migration and gender - 2013 Rural) append


*Education 2016
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons type team) nogen
svyset ea [pweight=weight_cons], strata(strata)
qui tabout edu_level_broad type using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & (type==1 | type==2), svy percent c(col se) npos(col) sebnone h1(Education level - 2016) append


*Education 2013
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
merge m:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen assert(match) keepusing(cluster strata)
svyset cluster [pweight=weight], strata(strata)
qui tabout edlevel urban using "${gsdOutput}/Somaliland_Comparison_3.xls", svy percent c(col se) npos(col) sebnone h1(Education level - 2013) append


*School attendance 2016
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons type team poorPPP) nogen
svyset ea [pweight=weight_cons], strata(strata)
qui tabout hhm_edu_current type using "${gsdOutput}/Somaliland_Comparison_4.xls" if age<=25 &  team==1 & (type==1 | type==2), svy percent c(col se) npos(col) sebnone h1(School attendance - 2016) replace
qui tabout hhm_edu_current type using "${gsdOutput}/Somaliland_Comparison_4.xls" if age<=25 &  team==1 & (type==1 | type==2) & poorPPP==1, svy percent c(col se) npos(col) sebnone h1(School attendance (poor) - 2016) append
qui tabout hhm_edu_current type using "${gsdOutput}/Somaliland_Comparison_4.xls" if age<=25 &  team==1 & (type==1 | type==2) & poorPPP==0, svy percent c(col se) npos(col) sebnone h1(School attendance (non-poor) - 2016) append


*School attendance 2013
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
merge m:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen assert(match) keepusing(cluster strata)
merge m:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
svyset cluster [pweight=weight], strata(strata)
qui tabout edu_attend urban if S3_A06_1>5 & S3_A06_1<=25 using "${gsdOutput}/Somaliland_Comparison_4.xls", svy percent c(col se) npos(col) sebnone h1(School attendance - 2013) append
qui tabout edu_attend urban if S3_A06_1>5 & S3_A06_1<=25 & poorPPP==1 using "${gsdOutput}/Somaliland_Comparison_4.xls", svy percent c(col se) npos(col) sebnone h1(School attendance (poor)- 2013) append
qui tabout edu_attend urban if S3_A06_1>5 & S3_A06_1<=25 & poorPPP==0 using "${gsdOutput}/Somaliland_Comparison_4.xls", svy percent c(col se) npos(col) sebnone h1(School attendance (non-poor)- 2013) append


*Education 2016 (by poverty status)
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons type team poorPPP) nogen
svyset ea [pweight=weight_cons], strata(strata)
qui tabout edu_level_broad type using "${gsdOutput}/Somaliland_Comparison_4.xls" if team==1 & (type==1 | type==2) & poorPPP==1, svy percent c(col se) npos(col) sebnone h1(Education level (poor) - 2016) append
qui tabout edu_level_broad type using "${gsdOutput}/Somaliland_Comparison_4.xls" if team==1 & (type==1 | type==2) & poorPPP==0, svy percent c(col se) npos(col) sebnone h1(Education level (non-poor) - 2016) append


*Education 2013 (by poverty status)
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
merge m:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen assert(match) keepusing(cluster strata)
merge m:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
svyset cluster [pweight=weight], strata(strata)
qui tabout edlevel urban if poorPPP==1 using "${gsdOutput}/Somaliland_Comparison_4.xls", svy percent c(col se) npos(col) sebnone h1(Education level (poor) - 2013) append
qui tabout edlevel urban if poorPPP==0 using "${gsdOutput}/Somaliland_Comparison_4.xls", svy percent c(col se) npos(col) sebnone h1(Education level (non-poor) - 2013) append


*Employed/Unemployed 2016 
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons type team) nogen
svyset ea [pweight=weight_cons], strata(strata)
qui tabout status_7d type using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & (type==1 | type==2), svy percent c(col se) npos(col) sebnone h1(Employed/Unemployed - 2016) append


*Employed/Unemployed 2013 
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
merge m:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen assert(match) keepusing(cluster strata)
svyset cluster [pweight=weight], strata(strata)
qui tabout economic_status urban using "${gsdOutput}/Somaliland_Comparison_3.xls", svy percent c(col se) npos(col) sebnone h1(Employed/Unemployed - 2013) append


*Inactive reasons 2016
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons type team) nogen
svyset ea [pweight=weight_cons], strata(strata)
qui tabout inac_narrow type using "${gsdOutput}/Somaliland_Comparison_3.xls" if (type==1 | type==2) & team!=1, svy percent c(col se) npos(col) sebnone h1(Inactive reasons - 2016 Somali) append
qui tabout inac_narrow type using "${gsdOutput}/Somaliland_Comparison_3.xls" if team==1 & (type==1 | type==2), svy percent c(col se) npos(col) sebnone h1(Inactive reasons - 2016 NW region) append


*2016: No. of observations needed for the t-test 
use "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", clear
merge 1:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta",nogen keep(match) keepusing(hhh_gender)
qui tabout type poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if remit12m==1 & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h1(Sample size 2016 - Urban/rural & Poor/Non-Poor: recevied remittances) append
qui tabout type poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if !missing(hhsize) & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h1(Sample size 2016 - Urban/rural & Poor/Non-Poor: household size) append
qui tabout type poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if hhh_gender==0 & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h1(Sample size 2016 - Urban/rural & Poor/Non-Poor: hhh Female) append
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", nogen keep(match master) keepusing(poorPPP)
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons type) nogen
qui tabout type poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if literacy==1 & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h1(Sample size 2016 - Urban/rural & Poor/Non-Poor: literate) append
qui tabout type poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if lfp_7d==1 & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h1(Sample size 2016 - Urban/rural & Poor/Non-Poor: lfp) append
qui tabout type gender using "${gsdOutput}/Somaliland_Comparison_3.xls"  if hh_alwayslived==0 & age>=25 & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h1(Sample size 2016 - Urban/rural - Men/Women: migration 25+) append
qui tabout type poorPPP using "${gsdOutput}/Somaliland_Comparison_4.xls" if hhm_edu_current==1 & age<=25 & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h1(Sample size 2016 - Urban/rural & Poor/Non-Poor: school attendance) append
qui tabout type poorPPP using "${gsdOutput}/Somaliland_Comparison_4.xls" if edu_level_broad==0 & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h1(Sample size 2016 - Urban/rural & Poor/Non-Poor: no education) append
use "${gsdData}/1-CleanOutput/hh.dta", clear 
gen zone=3
merge m:1 zone using "${gsdData}/1-CleanInput/HFS Exchange Rate Survey.dta", nogen keepusing(global_er) keep(match master) 
merge m:1 zone using "${gsdData}/1-CleanTemp/inflation.dta", nogen keepusing(gg) assert(match using) keep(match)
merge m:1 astrata using "${gsdData}/1-CleanTemp/food-deflator.dta", nogen assert(match) keep(match) keepusing(deflator)
replace remit12m_usd=remit12m_usd/deflator
gen rate_ppp=10731
gen remitt_2011_ppp=((remit12m_usd*global_er)/gg)/rate_ppp
drop poorPPP
merge 1:1 strata ea block hh using "${gsdTemp}/Somaliland_Comparison_Poverty_2016.dta", nogen keep(match) keepusing(poorPPP)
qui tabout type poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls"  if !missing(remitt_2011_ppp) & team==1 & (type==1 | type==2), c(freq) f(3) npos(col) h1(Sample size 2016 - Urban/rural - Poor/Non-Poor: value of remittances for receivers) append



*2013: No. of observations needed for the t-test 
use "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", clear
qui tabout urban poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls"  if dummy_remitt==1, c(freq) f(3) npos(col) h1(Sample size 2013 - Urban/rural & Poor/Non-Poor: recevied remittances) append
qui tabout urban poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls"  if !missing(S1_HHSIZE), c(freq) f(3) npos(col) h1(Sample size 2013 - Urban/rural & Poor/Non-Poor: household size) append
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
gen pre_hhh_female=1 if S3_A05==1 & S3_A04==2
replace pre_hhh_female=0 if pre_hhh_female==.
bys hhid: egen hhh_female=max(pre_hhh_female)
merge m:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen assert(match) keepusing(cluster strata)
merge m:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
qui tabout urban poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls"  if lit_any==1, c(freq) f(3) npos(col) h1(Sample size 2013 - Urban/rural & Poor/Non-Poor: literate) append
qui tabout urban poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls"  if lfp==1, c(freq) f(3) npos(col) h1(Sample size 2013 - Urban/rural & Poor/Non-Poor: lfp) append
qui tabout urban S3_A04 using "${gsdOutput}/Somaliland_Comparison_3.xls" if S3_AB02==2, c(freq) f(3) npos(col) h1(Sample size 2013 - Urban/rural - Men/Women: migration 25+) append
collapse (max) hhh_female, by( hhid weight cluster strata urban poorPPP)
qui tabout urban poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if hhh_female==1, c(freq) f(3) npos(col) h1(Sample size 2013 - Urban/rural & Poor/Non-Poor: hhh Female) append
use "${gsdData}/1-CleanInput/SLHS13/hh.dta", clear
gen remit1 = S4_J03C107 * 1000^(S4_J03C_U107-1)
gen remit2 = S4_J03C108 * 1000^(S4_J03C_U108-1)
gen remit =0
replace remit = remit + remit1 if remit1<.
replace remit = remit + remit2 if remit2<.
replace remit= remit/paasche 
replace remit=. if remit==0
label var remit "Annual remittance per hh in SLD Shilling"
gen remitt_2011_ppp=(((remit/6733.69)*20360.53)/1.584)/10731
merge 1:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
qui tabout urban poorPPP using "${gsdOutput}/Somaliland_Comparison_3.xls" if !missing(remitt_2011_ppp), c(freq) f(3) npos(col) h1(Sample size 2013 - Urban/rural - Poor/Non-Poor: value of remittances for receivers) append
use "${gsdData}/1-CleanInput/SLHS13/hhm.dta", clear
merge m:1 hhid using "${gsdData}/1-CleanInput/SLHS13/hh.dta", nogen assert(match) keepusing(cluster strata)
merge m:1 hhid using "${gsdTemp}/Somaliland_Comparison_Poverty_2013.dta", nogen keep(match) keepusing(poorPPP)
qui tabout urban poorPPP using "${gsdOutput}/Somaliland_Comparison_4.xls"  if edu_attend>0 & S3_A06_1>5 & S3_A06_1<=25 , c(freq) f(3) npos(col) h1(Sample size 2013 - Urban/rural & Poor/Non-Poor: school attendance) append
qui tabout urban poorPPP using "${gsdOutput}/Somaliland_Comparison_4.xls"  if edlevel==0, c(freq) f(3) npos(col) h1(Sample size 2013 - Urban/rural & Poor/Non-Poor: no education) append



* Put all created sheets into one excel document
foreach i of numlist 0/4 {
	insheet using "${gsdOutput}/Somaliland_Comparison_`i'.xls", clear nonames tab
	export excel using "${gsdOutput}/NorthWest_Figures_Final.xlsx", sheetreplace sheet("Raw_Data_`i'") 
	erase "${gsdOutput}/Somaliland_Comparison_`i'.xls"
}
